Class: Aws::IoTWireless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTWireless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotwireless/client.rb,
sig/client.rbs
Overview
An API client for IoTWireless. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTWireless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateAwsAccountWithPartnerAccountResponseSuccess, _AssociateMulticastGroupWithFuotaTaskResponseSuccess, _AssociateWirelessDeviceWithFuotaTaskResponseSuccess, _AssociateWirelessDeviceWithMulticastGroupResponseSuccess, _AssociateWirelessDeviceWithThingResponseSuccess, _AssociateWirelessGatewayWithCertificateResponseSuccess, _AssociateWirelessGatewayWithThingResponseSuccess, _CancelMulticastGroupSessionResponseSuccess, _CreateDestinationResponseSuccess, _CreateDeviceProfileResponseSuccess, _CreateFuotaTaskResponseSuccess, _CreateMulticastGroupResponseSuccess, _CreateNetworkAnalyzerConfigurationResponseSuccess, _CreateServiceProfileResponseSuccess, _CreateWirelessDeviceResponseSuccess, _CreateWirelessGatewayResponseSuccess, _CreateWirelessGatewayTaskDefinitionResponseSuccess, _CreateWirelessGatewayTaskResponseSuccess, _DeleteDestinationResponseSuccess, _DeleteDeviceProfileResponseSuccess, _DeleteFuotaTaskResponseSuccess, _DeleteMulticastGroupResponseSuccess, _DeleteNetworkAnalyzerConfigurationResponseSuccess, _DeleteQueuedMessagesResponseSuccess, _DeleteServiceProfileResponseSuccess, _DeleteWirelessDeviceImportTaskResponseSuccess, _DeleteWirelessDeviceResponseSuccess, _DeleteWirelessGatewayResponseSuccess, _DeleteWirelessGatewayTaskDefinitionResponseSuccess, _DeleteWirelessGatewayTaskResponseSuccess, _DeregisterWirelessDeviceResponseSuccess, _DisassociateAwsAccountFromPartnerAccountResponseSuccess, _DisassociateMulticastGroupFromFuotaTaskResponseSuccess, _DisassociateWirelessDeviceFromFuotaTaskResponseSuccess, _DisassociateWirelessDeviceFromMulticastGroupResponseSuccess, _DisassociateWirelessDeviceFromThingResponseSuccess, _DisassociateWirelessGatewayFromCertificateResponseSuccess, _DisassociateWirelessGatewayFromThingResponseSuccess, _GetDestinationResponseSuccess, _GetDeviceProfileResponseSuccess, _GetEventConfigurationByResourceTypesResponseSuccess, _GetFuotaTaskResponseSuccess, _GetLogLevelsByResourceTypesResponseSuccess, _GetMetricConfigurationResponseSuccess, _GetMetricsResponseSuccess, _GetMulticastGroupResponseSuccess, _GetMulticastGroupSessionResponseSuccess, _GetNetworkAnalyzerConfigurationResponseSuccess, _GetPartnerAccountResponseSuccess, _GetPositionConfigurationResponseSuccess, _GetPositionEstimateResponseSuccess, _GetPositionResponseSuccess, _GetResourceEventConfigurationResponseSuccess, _GetResourceLogLevelResponseSuccess, _GetResourcePositionResponseSuccess, _GetServiceEndpointResponseSuccess, _GetServiceProfileResponseSuccess, _GetWirelessDeviceImportTaskResponseSuccess, _GetWirelessDeviceResponseSuccess, _GetWirelessDeviceStatisticsResponseSuccess, _GetWirelessGatewayCertificateResponseSuccess, _GetWirelessGatewayFirmwareInformationResponseSuccess, _GetWirelessGatewayResponseSuccess, _GetWirelessGatewayStatisticsResponseSuccess, _GetWirelessGatewayTaskDefinitionResponseSuccess, _GetWirelessGatewayTaskResponseSuccess, _ListDestinationsResponseSuccess, _ListDeviceProfilesResponseSuccess, _ListDevicesForWirelessDeviceImportTaskResponseSuccess, _ListEventConfigurationsResponseSuccess, _ListFuotaTasksResponseSuccess, _ListMulticastGroupsByFuotaTaskResponseSuccess, _ListMulticastGroupsResponseSuccess, _ListNetworkAnalyzerConfigurationsResponseSuccess, _ListPartnerAccountsResponseSuccess, _ListPositionConfigurationsResponseSuccess, _ListQueuedMessagesResponseSuccess, _ListServiceProfilesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWirelessDeviceImportTasksResponseSuccess, _ListWirelessDevicesResponseSuccess, _ListWirelessGatewayTaskDefinitionsResponseSuccess, _ListWirelessGatewaysResponseSuccess, _PutPositionConfigurationResponseSuccess, _PutResourceLogLevelResponseSuccess, _ResetAllResourceLogLevelsResponseSuccess, _ResetResourceLogLevelResponseSuccess, _SendDataToMulticastGroupResponseSuccess, _SendDataToWirelessDeviceResponseSuccess, _StartBulkAssociateWirelessDeviceWithMulticastGroupResponseSuccess, _StartBulkDisassociateWirelessDeviceFromMulticastGroupResponseSuccess, _StartFuotaTaskResponseSuccess, _StartMulticastGroupSessionResponseSuccess, _StartSingleWirelessDeviceImportTaskResponseSuccess, _StartWirelessDeviceImportTaskResponseSuccess, _TagResourceResponseSuccess, _TestWirelessDeviceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDestinationResponseSuccess, _UpdateEventConfigurationByResourceTypesResponseSuccess, _UpdateFuotaTaskResponseSuccess, _UpdateLogLevelsByResourceTypesResponseSuccess, _UpdateMetricConfigurationResponseSuccess, _UpdateMulticastGroupResponseSuccess, _UpdateNetworkAnalyzerConfigurationResponseSuccess, _UpdatePartnerAccountResponseSuccess, _UpdatePositionResponseSuccess, _UpdateResourceEventConfigurationResponseSuccess, _UpdateResourcePositionResponseSuccess, _UpdateWirelessDeviceImportTaskResponseSuccess, _UpdateWirelessDeviceResponseSuccess, _UpdateWirelessGatewayResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_aws_account_with_partner_account(params = {}) ⇒ Types::AssociateAwsAccountWithPartnerAccountResponse
Associates a partner account with your AWS account.
-
#associate_multicast_group_with_fuota_task(params = {}) ⇒ Struct
Associate a multicast group with a FUOTA task.
-
#associate_wireless_device_with_fuota_task(params = {}) ⇒ Struct
Associate a wireless device with a FUOTA task.
-
#associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Associates a wireless device with a multicast group.
-
#associate_wireless_device_with_thing(params = {}) ⇒ Struct
Associates a wireless device with a thing.
-
#associate_wireless_gateway_with_certificate(params = {}) ⇒ Types::AssociateWirelessGatewayWithCertificateResponse
Associates a wireless gateway with a certificate.
-
#associate_wireless_gateway_with_thing(params = {}) ⇒ Struct
Associates a wireless gateway with a thing.
-
#cancel_multicast_group_session(params = {}) ⇒ Struct
Cancels an existing multicast group session.
-
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Creates a new destination that maps a device message to an AWS IoT rule.
-
#create_device_profile(params = {}) ⇒ Types::CreateDeviceProfileResponse
Creates a new device profile.
-
#create_fuota_task(params = {}) ⇒ Types::CreateFuotaTaskResponse
Creates a FUOTA task.
-
#create_multicast_group(params = {}) ⇒ Types::CreateMulticastGroupResponse
Creates a multicast group.
-
#create_network_analyzer_configuration(params = {}) ⇒ Types::CreateNetworkAnalyzerConfigurationResponse
Creates a new network analyzer configuration.
-
#create_service_profile(params = {}) ⇒ Types::CreateServiceProfileResponse
Creates a new service profile.
-
#create_wireless_device(params = {}) ⇒ Types::CreateWirelessDeviceResponse
Provisions a wireless device.
-
#create_wireless_gateway(params = {}) ⇒ Types::CreateWirelessGatewayResponse
Provisions a wireless gateway.
-
#create_wireless_gateway_task(params = {}) ⇒ Types::CreateWirelessGatewayTaskResponse
Creates a task for a wireless gateway.
-
#create_wireless_gateway_task_definition(params = {}) ⇒ Types::CreateWirelessGatewayTaskDefinitionResponse
Creates a gateway task definition.
-
#delete_destination(params = {}) ⇒ Struct
Deletes a destination.
-
#delete_device_profile(params = {}) ⇒ Struct
Deletes a device profile.
-
#delete_fuota_task(params = {}) ⇒ Struct
Deletes a FUOTA task.
-
#delete_multicast_group(params = {}) ⇒ Struct
Deletes a multicast group if it is not in use by a FUOTA task.
-
#delete_network_analyzer_configuration(params = {}) ⇒ Struct
Deletes a network analyzer configuration.
-
#delete_queued_messages(params = {}) ⇒ Struct
Remove queued messages from the downlink queue.
-
#delete_service_profile(params = {}) ⇒ Struct
Deletes a service profile.
-
#delete_wireless_device(params = {}) ⇒ Struct
Deletes a wireless device.
-
#delete_wireless_device_import_task(params = {}) ⇒ Struct
Delete an import task.
-
#delete_wireless_gateway(params = {}) ⇒ Struct
Deletes a wireless gateway.
-
#delete_wireless_gateway_task(params = {}) ⇒ Struct
Deletes a wireless gateway task.
-
#delete_wireless_gateway_task_definition(params = {}) ⇒ Struct
Deletes a wireless gateway task definition.
-
#deregister_wireless_device(params = {}) ⇒ Struct
Deregister a wireless device from AWS IoT Wireless.
-
#disassociate_aws_account_from_partner_account(params = {}) ⇒ Struct
Disassociates your AWS account from a partner account.
-
#disassociate_multicast_group_from_fuota_task(params = {}) ⇒ Struct
Disassociates a multicast group from a FUOTA task.
-
#disassociate_wireless_device_from_fuota_task(params = {}) ⇒ Struct
Disassociates a wireless device from a FUOTA task.
-
#disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Disassociates a wireless device from a multicast group.
-
#disassociate_wireless_device_from_thing(params = {}) ⇒ Struct
Disassociates a wireless device from its currently associated thing.
-
#disassociate_wireless_gateway_from_certificate(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated certificate.
-
#disassociate_wireless_gateway_from_thing(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated thing.
-
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets information about a destination.
-
#get_device_profile(params = {}) ⇒ Types::GetDeviceProfileResponse
Gets information about a device profile.
-
#get_event_configuration_by_resource_types(params = {}) ⇒ Types::GetEventConfigurationByResourceTypesResponse
Get the event configuration based on resource types.
-
#get_fuota_task(params = {}) ⇒ Types::GetFuotaTaskResponse
Gets information about a FUOTA task.
-
#get_log_levels_by_resource_types(params = {}) ⇒ Types::GetLogLevelsByResourceTypesResponse
Returns current default log levels or log levels by resource types.
-
#get_metric_configuration(params = {}) ⇒ Types::GetMetricConfigurationResponse
Get the metric configuration status for this AWS account.
-
#get_metrics(params = {}) ⇒ Types::GetMetricsResponse
Get the summary metrics for this AWS account.
-
#get_multicast_group(params = {}) ⇒ Types::GetMulticastGroupResponse
Gets information about a multicast group.
-
#get_multicast_group_session(params = {}) ⇒ Types::GetMulticastGroupSessionResponse
Gets information about a multicast group session.
-
#get_network_analyzer_configuration(params = {}) ⇒ Types::GetNetworkAnalyzerConfigurationResponse
Get network analyzer configuration.
-
#get_partner_account(params = {}) ⇒ Types::GetPartnerAccountResponse
Gets information about a partner account.
-
#get_position(params = {}) ⇒ Types::GetPositionResponse
Get the position information for a given resource.
-
#get_position_configuration(params = {}) ⇒ Types::GetPositionConfigurationResponse
Get position configuration for a given resource.
-
#get_position_estimate(params = {}) ⇒ Types::GetPositionEstimateResponse
Get estimated position information as a payload in GeoJSON format.
-
#get_resource_event_configuration(params = {}) ⇒ Types::GetResourceEventConfigurationResponse
Get the event configuration for a particular resource identifier.
-
#get_resource_log_level(params = {}) ⇒ Types::GetResourceLogLevelResponse
Fetches the log-level override, if any, for a given resource ID and resource type..
-
#get_resource_position(params = {}) ⇒ Types::GetResourcePositionResponse
Get the position information for a given wireless device or a wireless gateway resource.
-
#get_service_endpoint(params = {}) ⇒ Types::GetServiceEndpointResponse
Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.
-
#get_service_profile(params = {}) ⇒ Types::GetServiceProfileResponse
Gets information about a service profile.
-
#get_wireless_device(params = {}) ⇒ Types::GetWirelessDeviceResponse
Gets information about a wireless device.
-
#get_wireless_device_import_task(params = {}) ⇒ Types::GetWirelessDeviceImportTaskResponse
Get information about an import task and count of device onboarding summary information for the import task.
-
#get_wireless_device_statistics(params = {}) ⇒ Types::GetWirelessDeviceStatisticsResponse
Gets operating information about a wireless device.
-
#get_wireless_gateway(params = {}) ⇒ Types::GetWirelessGatewayResponse
Gets information about a wireless gateway.
-
#get_wireless_gateway_certificate(params = {}) ⇒ Types::GetWirelessGatewayCertificateResponse
Gets the ID of the certificate that is currently associated with a wireless gateway.
-
#get_wireless_gateway_firmware_information(params = {}) ⇒ Types::GetWirelessGatewayFirmwareInformationResponse
Gets the firmware version and other information about a wireless gateway.
-
#get_wireless_gateway_statistics(params = {}) ⇒ Types::GetWirelessGatewayStatisticsResponse
Gets operating information about a wireless gateway.
-
#get_wireless_gateway_task(params = {}) ⇒ Types::GetWirelessGatewayTaskResponse
Gets information about a wireless gateway task.
-
#get_wireless_gateway_task_definition(params = {}) ⇒ Types::GetWirelessGatewayTaskDefinitionResponse
Gets information about a wireless gateway task definition.
-
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Lists the destinations registered to your AWS account.
-
#list_device_profiles(params = {}) ⇒ Types::ListDeviceProfilesResponse
Lists the device profiles registered to your AWS account.
-
#list_devices_for_wireless_device_import_task(params = {}) ⇒ Types::ListDevicesForWirelessDeviceImportTaskResponse
List the Sidewalk devices in an import task and their onboarding status.
-
#list_event_configurations(params = {}) ⇒ Types::ListEventConfigurationsResponse
List event configurations where at least one event topic has been enabled.
-
#list_fuota_tasks(params = {}) ⇒ Types::ListFuotaTasksResponse
Lists the FUOTA tasks registered to your AWS account.
-
#list_multicast_groups(params = {}) ⇒ Types::ListMulticastGroupsResponse
Lists the multicast groups registered to your AWS account.
-
#list_multicast_groups_by_fuota_task(params = {}) ⇒ Types::ListMulticastGroupsByFuotaTaskResponse
List all multicast groups associated with a FUOTA task.
-
#list_network_analyzer_configurations(params = {}) ⇒ Types::ListNetworkAnalyzerConfigurationsResponse
Lists the network analyzer configurations.
-
#list_partner_accounts(params = {}) ⇒ Types::ListPartnerAccountsResponse
Lists the partner accounts associated with your AWS account.
-
#list_position_configurations(params = {}) ⇒ Types::ListPositionConfigurationsResponse
List position configurations for a given resource, such as positioning solvers.
-
#list_queued_messages(params = {}) ⇒ Types::ListQueuedMessagesResponse
List queued messages in the downlink queue.
-
#list_service_profiles(params = {}) ⇒ Types::ListServiceProfilesResponse
Lists the service profiles registered to your AWS account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
-
#list_wireless_device_import_tasks(params = {}) ⇒ Types::ListWirelessDeviceImportTasksResponse
List of import tasks and summary information of onboarding status of devices in each import task.
-
#list_wireless_devices(params = {}) ⇒ Types::ListWirelessDevicesResponse
Lists the wireless devices registered to your AWS account.
-
#list_wireless_gateway_task_definitions(params = {}) ⇒ Types::ListWirelessGatewayTaskDefinitionsResponse
List the wireless gateway tasks definitions registered to your AWS account.
-
#list_wireless_gateways(params = {}) ⇒ Types::ListWirelessGatewaysResponse
Lists the wireless gateways registered to your AWS account.
-
#put_position_configuration(params = {}) ⇒ Struct
Put position configuration for a given resource.
-
#put_resource_log_level(params = {}) ⇒ Struct
Sets the log-level override for a resource ID and resource type.
-
#reset_all_resource_log_levels(params = {}) ⇒ Struct
Removes the log-level overrides for all resources; wireless devices, wireless gateways, and FUOTA tasks.
-
#reset_resource_log_level(params = {}) ⇒ Struct
Removes the log-level override, if any, for a specific resource ID and resource type.
-
#send_data_to_multicast_group(params = {}) ⇒ Types::SendDataToMulticastGroupResponse
Sends the specified data to a multicast group.
-
#send_data_to_wireless_device(params = {}) ⇒ Types::SendDataToWirelessDeviceResponse
Sends a decrypted application data frame to a device.
-
#start_bulk_associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Starts a bulk association of all qualifying wireless devices with a multicast group.
-
#start_bulk_disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Starts a bulk disassociatin of all qualifying wireless devices from a multicast group.
-
#start_fuota_task(params = {}) ⇒ Struct
Starts a FUOTA task.
-
#start_multicast_group_session(params = {}) ⇒ Struct
Starts a multicast group session.
-
#start_single_wireless_device_import_task(params = {}) ⇒ Types::StartSingleWirelessDeviceImportTaskResponse
Start import task for a single wireless device.
-
#start_wireless_device_import_task(params = {}) ⇒ Types::StartWirelessDeviceImportTaskResponse
Start import task for provisioning Sidewalk devices in bulk using an S3 CSV file.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#test_wireless_device(params = {}) ⇒ Types::TestWirelessDeviceResponse
Simulates a provisioned device by sending an uplink data payload of
Hello. -
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
-
#update_destination(params = {}) ⇒ Struct
Updates properties of a destination.
-
#update_event_configuration_by_resource_types(params = {}) ⇒ Struct
Update the event configuration based on resource types.
-
#update_fuota_task(params = {}) ⇒ Struct
Updates properties of a FUOTA task.
-
#update_log_levels_by_resource_types(params = {}) ⇒ Struct
Set default log level, or log levels by resource types.
-
#update_metric_configuration(params = {}) ⇒ Struct
Update the summary metric configuration.
-
#update_multicast_group(params = {}) ⇒ Struct
Updates properties of a multicast group session.
-
#update_network_analyzer_configuration(params = {}) ⇒ Struct
Update network analyzer configuration.
-
#update_partner_account(params = {}) ⇒ Struct
Updates properties of a partner account.
-
#update_position(params = {}) ⇒ Struct
Update the position information of a resource.
-
#update_resource_event_configuration(params = {}) ⇒ Struct
Update the event configuration for a particular resource identifier.
-
#update_resource_position(params = {}) ⇒ Struct
Update the position information of a given wireless device or a wireless gateway resource.
-
#update_wireless_device(params = {}) ⇒ Struct
Updates properties of a wireless device.
-
#update_wireless_device_import_task(params = {}) ⇒ Struct
Update an import task to add more devices to the task.
-
#update_wireless_gateway(params = {}) ⇒ Struct
Updates properties of a wireless gateway.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5498 5499 5500 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5498 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5501 5502 5503 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5501 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_aws_account_with_partner_account(params = {}) ⇒ Types::AssociateAwsAccountWithPartnerAccountResponse
Associates a partner account with your AWS account.
87 |
# File 'sig/client.rbs', line 87
def associate_aws_account_with_partner_account: (
|
#associate_multicast_group_with_fuota_task(params = {}) ⇒ Struct
Associate a multicast group with a FUOTA task.
106 |
# File 'sig/client.rbs', line 106
def associate_multicast_group_with_fuota_task: (
|
#associate_wireless_device_with_fuota_task(params = {}) ⇒ Struct
Associate a wireless device with a FUOTA task.
116 |
# File 'sig/client.rbs', line 116
def associate_wireless_device_with_fuota_task: (
|
#associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Associates a wireless device with a multicast group.
126 |
# File 'sig/client.rbs', line 126
def associate_wireless_device_with_multicast_group: (
|
#associate_wireless_device_with_thing(params = {}) ⇒ Struct
Associates a wireless device with a thing.
136 |
# File 'sig/client.rbs', line 136
def associate_wireless_device_with_thing: (
|
#associate_wireless_gateway_with_certificate(params = {}) ⇒ Types::AssociateWirelessGatewayWithCertificateResponse
Associates a wireless gateway with a certificate.
147 |
# File 'sig/client.rbs', line 147
def associate_wireless_gateway_with_certificate: (
|
#associate_wireless_gateway_with_thing(params = {}) ⇒ Struct
Associates a wireless gateway with a thing.
157 |
# File 'sig/client.rbs', line 157
def associate_wireless_gateway_with_thing: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5471 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTWireless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotwireless' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_multicast_group_session(params = {}) ⇒ Struct
Cancels an existing multicast group session.
167 |
# File 'sig/client.rbs', line 167
def cancel_multicast_group_session: (
|
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Creates a new destination that maps a device message to an AWS IoT rule.
178 |
# File 'sig/client.rbs', line 178
def create_destination: (
|
#create_device_profile(params = {}) ⇒ Types::CreateDeviceProfileResponse
Creates a new device profile.
200 |
# File 'sig/client.rbs', line 200
def create_device_profile: (
|
#create_fuota_task(params = {}) ⇒ Types::CreateFuotaTaskResponse
Creates a FUOTA task.
241 |
# File 'sig/client.rbs', line 241
def create_fuota_task: (
|
#create_multicast_group(params = {}) ⇒ Types::CreateMulticastGroupResponse
Creates a multicast group.
269 |
# File 'sig/client.rbs', line 269
def create_multicast_group: (
|
#create_network_analyzer_configuration(params = {}) ⇒ Types::CreateNetworkAnalyzerConfigurationResponse
Creates a new network analyzer configuration.
289 |
# File 'sig/client.rbs', line 289
def create_network_analyzer_configuration: (
|
#create_service_profile(params = {}) ⇒ Types::CreateServiceProfileResponse
Creates a new service profile.
316 |
# File 'sig/client.rbs', line 316
def create_service_profile: (
|
#create_wireless_device(params = {}) ⇒ Types::CreateWirelessDeviceResponse
Provisions a wireless device.
345 |
# File 'sig/client.rbs', line 345
def create_wireless_device: (
|
#create_wireless_gateway(params = {}) ⇒ Types::CreateWirelessGatewayResponse
Provisions a wireless gateway.
-
If you specify a
GatewayEuivalue that already exists. -
If you used a
ClientRequestTokenwith the same parameters within the last 10 minutes.
To avoid this error, make sure that you use unique identifiers and parameters for each request within the specified time period.
425 |
# File 'sig/client.rbs', line 425
def create_wireless_gateway: (
|
#create_wireless_gateway_task(params = {}) ⇒ Types::CreateWirelessGatewayTaskResponse
Creates a task for a wireless gateway.
458 |
# File 'sig/client.rbs', line 458
def create_wireless_gateway_task: (
|
#create_wireless_gateway_task_definition(params = {}) ⇒ Types::CreateWirelessGatewayTaskDefinitionResponse
Creates a gateway task definition.
470 |
# File 'sig/client.rbs', line 470
def create_wireless_gateway_task_definition: (
|
#delete_destination(params = {}) ⇒ Struct
Deletes a destination.
505 |
# File 'sig/client.rbs', line 505
def delete_destination: (
|
#delete_device_profile(params = {}) ⇒ Struct
Deletes a device profile.
514 |
# File 'sig/client.rbs', line 514
def delete_device_profile: (
|
#delete_fuota_task(params = {}) ⇒ Struct
Deletes a FUOTA task.
523 |
# File 'sig/client.rbs', line 523
def delete_fuota_task: (
|
#delete_multicast_group(params = {}) ⇒ Struct
Deletes a multicast group if it is not in use by a FUOTA task.
532 |
# File 'sig/client.rbs', line 532
def delete_multicast_group: (
|
#delete_network_analyzer_configuration(params = {}) ⇒ Struct
Deletes a network analyzer configuration.
541 |
# File 'sig/client.rbs', line 541
def delete_network_analyzer_configuration: (
|
#delete_queued_messages(params = {}) ⇒ Struct
Remove queued messages from the downlink queue.
550 |
# File 'sig/client.rbs', line 550
def delete_queued_messages: (
|
#delete_service_profile(params = {}) ⇒ Struct
Deletes a service profile.
561 |
# File 'sig/client.rbs', line 561
def delete_service_profile: (
|
#delete_wireless_device(params = {}) ⇒ Struct
Deletes a wireless device.
570 |
# File 'sig/client.rbs', line 570
def delete_wireless_device: (
|
#delete_wireless_device_import_task(params = {}) ⇒ Struct
Delete an import task.
579 |
# File 'sig/client.rbs', line 579
def delete_wireless_device_import_task: (
|
#delete_wireless_gateway(params = {}) ⇒ Struct
Deletes a wireless gateway.
-
If you specify a
GatewayEuivalue that already exists. -
If you used a
ClientRequestTokenwith the same parameters within the last 10 minutes.
To avoid this error, make sure that you use unique identifiers and parameters for each request within the specified time period.
588 |
# File 'sig/client.rbs', line 588
def delete_wireless_gateway: (
|
#delete_wireless_gateway_task(params = {}) ⇒ Struct
Deletes a wireless gateway task.
597 |
# File 'sig/client.rbs', line 597
def delete_wireless_gateway_task: (
|
#delete_wireless_gateway_task_definition(params = {}) ⇒ Struct
Deletes a wireless gateway task definition. Deleting this task definition does not affect tasks that are currently in progress.
606 |
# File 'sig/client.rbs', line 606
def delete_wireless_gateway_task_definition: (
|
#deregister_wireless_device(params = {}) ⇒ Struct
Deregister a wireless device from AWS IoT Wireless.
615 |
# File 'sig/client.rbs', line 615
def deregister_wireless_device: (
|
#disassociate_aws_account_from_partner_account(params = {}) ⇒ Struct
Disassociates your AWS account from a partner account. If
PartnerAccountId and PartnerType are null, disassociates your
AWS account from all partner accounts.
625 |
# File 'sig/client.rbs', line 625
def disassociate_aws_account_from_partner_account: (
|
#disassociate_multicast_group_from_fuota_task(params = {}) ⇒ Struct
Disassociates a multicast group from a FUOTA task.
635 |
# File 'sig/client.rbs', line 635
def disassociate_multicast_group_from_fuota_task: (
|
#disassociate_wireless_device_from_fuota_task(params = {}) ⇒ Struct
Disassociates a wireless device from a FUOTA task.
645 |
# File 'sig/client.rbs', line 645
def disassociate_wireless_device_from_fuota_task: (
|
#disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Disassociates a wireless device from a multicast group.
655 |
# File 'sig/client.rbs', line 655
def disassociate_wireless_device_from_multicast_group: (
|
#disassociate_wireless_device_from_thing(params = {}) ⇒ Struct
Disassociates a wireless device from its currently associated thing.
665 |
# File 'sig/client.rbs', line 665
def disassociate_wireless_device_from_thing: (
|
#disassociate_wireless_gateway_from_certificate(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated certificate.
674 |
# File 'sig/client.rbs', line 674
def disassociate_wireless_gateway_from_certificate: (
|
#disassociate_wireless_gateway_from_thing(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated thing.
683 |
# File 'sig/client.rbs', line 683
def disassociate_wireless_gateway_from_thing: (
|
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets information about a destination.
698 |
# File 'sig/client.rbs', line 698
def get_destination: (
|
#get_device_profile(params = {}) ⇒ Types::GetDeviceProfileResponse
Gets information about a device profile.
712 |
# File 'sig/client.rbs', line 712
def get_device_profile: (
|
#get_event_configuration_by_resource_types(params = {}) ⇒ Types::GetEventConfigurationByResourceTypesResponse
Get the event configuration based on resource types.
726 |
# File 'sig/client.rbs', line 726
def get_event_configuration_by_resource_types: (
|
#get_fuota_task(params = {}) ⇒ Types::GetFuotaTaskResponse
Gets information about a FUOTA task.
747 |
# File 'sig/client.rbs', line 747
def get_fuota_task: (
|
#get_log_levels_by_resource_types(params = {}) ⇒ Types::GetLogLevelsByResourceTypesResponse
Returns current default log levels or log levels by resource types. Based on the resource type, log levels can be returned for wireless device, wireless gateway, or FUOTA task log options.
760 |
# File 'sig/client.rbs', line 760
def get_log_levels_by_resource_types: (
|
#get_metric_configuration(params = {}) ⇒ Types::GetMetricConfigurationResponse
Get the metric configuration status for this AWS account.
769 |
# File 'sig/client.rbs', line 769
def get_metric_configuration: (
|
#get_metrics(params = {}) ⇒ Types::GetMetricsResponse
Get the summary metrics for this AWS account.
778 |
# File 'sig/client.rbs', line 778
def get_metrics: (
|
#get_multicast_group(params = {}) ⇒ Types::GetMulticastGroupResponse
Gets information about a multicast group.
808 |
# File 'sig/client.rbs', line 808
def get_multicast_group: (
|
#get_multicast_group_session(params = {}) ⇒ Types::GetMulticastGroupSessionResponse
Gets information about a multicast group session.
818 |
# File 'sig/client.rbs', line 818
def get_multicast_group_session: (
|
#get_network_analyzer_configuration(params = {}) ⇒ Types::GetNetworkAnalyzerConfigurationResponse
Get network analyzer configuration.
834 |
# File 'sig/client.rbs', line 834
def get_network_analyzer_configuration: (
|
#get_partner_account(params = {}) ⇒ Types::GetPartnerAccountResponse
Gets information about a partner account. If PartnerAccountId and
PartnerType are null, returns all partner accounts.
845 |
# File 'sig/client.rbs', line 845
def get_partner_account: (
|
#get_position(params = {}) ⇒ Types::GetPositionResponse
Get the position information for a given resource.
This action is no longer supported. Calls to retrieve the position information should use the GetResourcePosition API operation instead.
861 |
# File 'sig/client.rbs', line 861
def get_position: (
|
#get_position_configuration(params = {}) ⇒ Types::GetPositionConfigurationResponse
Get position configuration for a given resource.
This action is no longer supported. Calls to retrieve the position configuration should use the GetResourcePosition API operation instead.
873 |
# File 'sig/client.rbs', line 873
def get_position_configuration: (
|
#get_position_estimate(params = {}) ⇒ Types::GetPositionEstimateResponse
Get estimated position information as a payload in GeoJSON format. The payload measurement data is resolved using solvers that are provided by third-party vendors.
884 |
# File 'sig/client.rbs', line 884
def get_position_estimate: (
|
#get_resource_event_configuration(params = {}) ⇒ Types::GetResourceEventConfigurationResponse
Get the event configuration for a particular resource identifier.
1042 |
# File 'sig/client.rbs', line 1042
def get_resource_event_configuration: (
|
#get_resource_log_level(params = {}) ⇒ Types::GetResourceLogLevelResponse
Fetches the log-level override, if any, for a given resource ID and resource type..
1054 |
# File 'sig/client.rbs', line 1054
def get_resource_log_level: (
|
#get_resource_position(params = {}) ⇒ Types::GetResourcePositionResponse
Get the position information for a given wireless device or a wireless gateway resource. The position information uses the World Geodetic System (WGS84).
1065 |
# File 'sig/client.rbs', line 1065
def get_resource_position: (
|
#get_service_endpoint(params = {}) ⇒ Types::GetServiceEndpointResponse
Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.
1078 |
# File 'sig/client.rbs', line 1078
def get_service_endpoint: (
|
#get_service_profile(params = {}) ⇒ Types::GetServiceProfileResponse
Gets information about a service profile.
1091 |
# File 'sig/client.rbs', line 1091
def get_service_profile: (
|
#get_wireless_device(params = {}) ⇒ Types::GetWirelessDeviceResponse
Gets information about a wireless device.
1111 |
# File 'sig/client.rbs', line 1111
def get_wireless_device: (
|
#get_wireless_device_import_task(params = {}) ⇒ Types::GetWirelessDeviceImportTaskResponse
Get information about an import task and count of device onboarding summary information for the import task.
1133 |
# File 'sig/client.rbs', line 1133
def get_wireless_device_import_task: (
|
#get_wireless_device_statistics(params = {}) ⇒ Types::GetWirelessDeviceStatisticsResponse
Gets operating information about a wireless device.
1146 |
# File 'sig/client.rbs', line 1146
def get_wireless_device_statistics: (
|
#get_wireless_gateway(params = {}) ⇒ Types::GetWirelessGatewayResponse
Gets information about a wireless gateway.
1162 |
# File 'sig/client.rbs', line 1162
def get_wireless_gateway: (
|
#get_wireless_gateway_certificate(params = {}) ⇒ Types::GetWirelessGatewayCertificateResponse
Gets the ID of the certificate that is currently associated with a wireless gateway.
1174 |
# File 'sig/client.rbs', line 1174
def get_wireless_gateway_certificate: (
|
#get_wireless_gateway_firmware_information(params = {}) ⇒ Types::GetWirelessGatewayFirmwareInformationResponse
Gets the firmware version and other information about a wireless gateway.
1184 |
# File 'sig/client.rbs', line 1184
def get_wireless_gateway_firmware_information: (
|
#get_wireless_gateway_statistics(params = {}) ⇒ Types::GetWirelessGatewayStatisticsResponse
Gets operating information about a wireless gateway.
1196 |
# File 'sig/client.rbs', line 1196
def get_wireless_gateway_statistics: (
|
#get_wireless_gateway_task(params = {}) ⇒ Types::GetWirelessGatewayTaskResponse
Gets information about a wireless gateway task.
1210 |
# File 'sig/client.rbs', line 1210
def get_wireless_gateway_task: (
|
#get_wireless_gateway_task_definition(params = {}) ⇒ Types::GetWirelessGatewayTaskDefinitionResponse
Gets information about a wireless gateway task definition.
1223 |
# File 'sig/client.rbs', line 1223
def get_wireless_gateway_task_definition: (
|
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Lists the destinations registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1234 |
# File 'sig/client.rbs', line 1234
def list_destinations: (
|
#list_device_profiles(params = {}) ⇒ Types::ListDeviceProfilesResponse
Lists the device profiles registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1246 |
# File 'sig/client.rbs', line 1246
def list_device_profiles: (
|
#list_devices_for_wireless_device_import_task(params = {}) ⇒ Types::ListDevicesForWirelessDeviceImportTaskResponse
List the Sidewalk devices in an import task and their onboarding status.
1262 |
# File 'sig/client.rbs', line 1262
def list_devices_for_wireless_device_import_task: (
|
#list_event_configurations(params = {}) ⇒ Types::ListEventConfigurationsResponse
List event configurations where at least one event topic has been enabled.
1276 |
# File 'sig/client.rbs', line 1276
def list_event_configurations: (
|
#list_fuota_tasks(params = {}) ⇒ Types::ListFuotaTasksResponse
Lists the FUOTA tasks registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1289 |
# File 'sig/client.rbs', line 1289
def list_fuota_tasks: (
|
#list_multicast_groups(params = {}) ⇒ Types::ListMulticastGroupsResponse
Lists the multicast groups registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1301 |
# File 'sig/client.rbs', line 1301
def list_multicast_groups: (
|
#list_multicast_groups_by_fuota_task(params = {}) ⇒ Types::ListMulticastGroupsByFuotaTaskResponse
List all multicast groups associated with a FUOTA task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1313 |
# File 'sig/client.rbs', line 1313
def list_multicast_groups_by_fuota_task: (
|
#list_network_analyzer_configurations(params = {}) ⇒ Types::ListNetworkAnalyzerConfigurationsResponse
Lists the network analyzer configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1326 |
# File 'sig/client.rbs', line 1326
def list_network_analyzer_configurations: (
|
#list_partner_accounts(params = {}) ⇒ Types::ListPartnerAccountsResponse
Lists the partner accounts associated with your AWS account.
1338 |
# File 'sig/client.rbs', line 1338
def list_partner_accounts: (
|
#list_position_configurations(params = {}) ⇒ Types::ListPositionConfigurationsResponse
List position configurations for a given resource, such as positioning solvers.
This action is no longer supported. Calls to retrieve position information should use the GetResourcePosition API operation instead.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1350 |
# File 'sig/client.rbs', line 1350
def list_position_configurations: (
|
#list_queued_messages(params = {}) ⇒ Types::ListQueuedMessagesResponse
List queued messages in the downlink queue.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1363 |
# File 'sig/client.rbs', line 1363
def list_queued_messages: (
|
#list_service_profiles(params = {}) ⇒ Types::ListServiceProfilesResponse
Lists the service profiles registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1377 |
# File 'sig/client.rbs', line 1377
def list_service_profiles: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
1388 |
# File 'sig/client.rbs', line 1388
def list_tags_for_resource: (
|
#list_wireless_device_import_tasks(params = {}) ⇒ Types::ListWirelessDeviceImportTasksResponse
List of import tasks and summary information of onboarding status of devices in each import task.
1399 |
# File 'sig/client.rbs', line 1399
def list_wireless_device_import_tasks: (
|
#list_wireless_devices(params = {}) ⇒ Types::ListWirelessDevicesResponse
Lists the wireless devices registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1411 |
# File 'sig/client.rbs', line 1411
def list_wireless_devices: (
|
#list_wireless_gateway_task_definitions(params = {}) ⇒ Types::ListWirelessGatewayTaskDefinitionsResponse
List the wireless gateway tasks definitions registered to your AWS account.
1429 |
# File 'sig/client.rbs', line 1429
def list_wireless_gateway_task_definitions: (
|
#list_wireless_gateways(params = {}) ⇒ Types::ListWirelessGatewaysResponse
Lists the wireless gateways registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1442 |
# File 'sig/client.rbs', line 1442
def list_wireless_gateways: (
|
#put_position_configuration(params = {}) ⇒ Struct
Put position configuration for a given resource.
This action is no longer supported. Calls to update the position configuration should use the UpdateResourcePosition API operation instead.
1452 |
# File 'sig/client.rbs', line 1452
def put_position_configuration: (
|
#put_resource_log_level(params = {}) ⇒ Struct
Sets the log-level override for a resource ID and resource type. A limit of 200 log level override can be set per account.
1469 |
# File 'sig/client.rbs', line 1469
def put_resource_log_level: (
|
#reset_all_resource_log_levels(params = {}) ⇒ Struct
Removes the log-level overrides for all resources; wireless devices, wireless gateways, and FUOTA tasks.
1480 |
# File 'sig/client.rbs', line 1480
def reset_all_resource_log_levels: (
|
#reset_resource_log_level(params = {}) ⇒ Struct
Removes the log-level override, if any, for a specific resource ID and resource type. It can be used for a wireless device, a wireless gateway, or a FUOTA task.
1488 |
# File 'sig/client.rbs', line 1488
def reset_resource_log_level: (
|
#send_data_to_multicast_group(params = {}) ⇒ Types::SendDataToMulticastGroupResponse
Sends the specified data to a multicast group.
1499 |
# File 'sig/client.rbs', line 1499
def send_data_to_multicast_group: (
|
#send_data_to_wireless_device(params = {}) ⇒ Types::SendDataToWirelessDeviceResponse
Sends a decrypted application data frame to a device.
1515 |
# File 'sig/client.rbs', line 1515
def send_data_to_wireless_device: (
|
#start_bulk_associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Starts a bulk association of all qualifying wireless devices with a multicast group.
1546 |
# File 'sig/client.rbs', line 1546
def start_bulk_associate_wireless_device_with_multicast_group: (
|
#start_bulk_disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Starts a bulk disassociatin of all qualifying wireless devices from a multicast group.
1562 |
# File 'sig/client.rbs', line 1562
def start_bulk_disassociate_wireless_device_from_multicast_group: (
|
#start_fuota_task(params = {}) ⇒ Struct
Starts a FUOTA task.
1578 |
# File 'sig/client.rbs', line 1578
def start_fuota_task: (
|
#start_multicast_group_session(params = {}) ⇒ Struct
Starts a multicast group session.
1590 |
# File 'sig/client.rbs', line 1590
def start_multicast_group_session: (
|
#start_single_wireless_device_import_task(params = {}) ⇒ Types::StartSingleWirelessDeviceImportTaskResponse
Start import task for a single wireless device.
1608 |
# File 'sig/client.rbs', line 1608
def start_single_wireless_device_import_task: (
|
#start_wireless_device_import_task(params = {}) ⇒ Types::StartWirelessDeviceImportTaskResponse
Start import task for provisioning Sidewalk devices in bulk using an S3 CSV file.
1634 |
# File 'sig/client.rbs', line 1634
def start_wireless_device_import_task: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
1658 |
# File 'sig/client.rbs', line 1658
def tag_resource: (
|
#test_wireless_device(params = {}) ⇒ Types::TestWirelessDeviceResponse
Simulates a provisioned device by sending an uplink data payload of
Hello.
1674 |
# File 'sig/client.rbs', line 1674
def test_wireless_device: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
1683 |
# File 'sig/client.rbs', line 1683
def untag_resource: (
|
#update_destination(params = {}) ⇒ Struct
Updates properties of a destination.
1693 |
# File 'sig/client.rbs', line 1693
def update_destination: (
|
#update_event_configuration_by_resource_types(params = {}) ⇒ Struct
Update the event configuration based on resource types.
1706 |
# File 'sig/client.rbs', line 1706
def update_event_configuration_by_resource_types: (
|
#update_fuota_task(params = {}) ⇒ Struct
Updates properties of a FUOTA task.
1739 |
# File 'sig/client.rbs', line 1739
def update_fuota_task: (
|
#update_log_levels_by_resource_types(params = {}) ⇒ Struct
Set default log level, or log levels by resource types. This can be for wireless device, wireless gateway, or FUOTA task log options, and is used to control the log messages that'll be displayed in CloudWatch.
1759 |
# File 'sig/client.rbs', line 1759
def update_log_levels_by_resource_types: (
|
#update_metric_configuration(params = {}) ⇒ Struct
Update the summary metric configuration.
1804 |
# File 'sig/client.rbs', line 1804
def update_metric_configuration: (
|
#update_multicast_group(params = {}) ⇒ Struct
Updates properties of a multicast group session.
1815 |
# File 'sig/client.rbs', line 1815
def update_multicast_group: (
|
#update_network_analyzer_configuration(params = {}) ⇒ Struct
Update network analyzer configuration.
1827 |
# File 'sig/client.rbs', line 1827
def update_network_analyzer_configuration: (
|
#update_partner_account(params = {}) ⇒ Struct
Updates properties of a partner account.
1848 |
# File 'sig/client.rbs', line 1848
def update_partner_account: (
|
#update_position(params = {}) ⇒ Struct
Update the position information of a resource.
This action is no longer supported. Calls to update the position information should use the UpdateResourcePosition API operation instead.
1861 |
# File 'sig/client.rbs', line 1861
def update_position: (
|
#update_resource_event_configuration(params = {}) ⇒ Struct
Update the event configuration for a particular resource identifier.
1872 |
# File 'sig/client.rbs', line 1872
def update_resource_event_configuration: (
|
#update_resource_position(params = {}) ⇒ Struct
Update the position information of a given wireless device or a wireless gateway resource. The position coordinates are based on the World Geodetic System (WGS84).
1913 |
# File 'sig/client.rbs', line 1913
def update_resource_position: (
|
#update_wireless_device(params = {}) ⇒ Struct
Updates properties of a wireless device.
1924 |
# File 'sig/client.rbs', line 1924
def update_wireless_device: (
|
#update_wireless_device_import_task(params = {}) ⇒ Struct
Update an import task to add more devices to the task.
1966 |
# File 'sig/client.rbs', line 1966
def update_wireless_device_import_task: (
|
#update_wireless_gateway(params = {}) ⇒ Struct
Updates properties of a wireless gateway.
1978 |
# File 'sig/client.rbs', line 1978
def update_wireless_gateway: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5491 5492 5493 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5491 def waiter_names [] end |