Class: Aws::IoTWireless::Types::ApplicationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

LoRaWAN application configuration, which can be used to perform geolocation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_nameString

The name of the position data destination that describes the AWS IoT rule that processes the device’s position data for use by AWS IoT Core for LoRaWAN.



111
112
113
114
115
116
117
# File 'lib/aws-sdk-iotwireless/types.rb', line 111

class ApplicationConfig < Struct.new(
  :f_port,
  :type,
  :destination_name)
  SENSITIVE = []
  include Aws::Structure
end

#f_portInteger

The Fport value.



111
112
113
114
115
116
117
# File 'lib/aws-sdk-iotwireless/types.rb', line 111

class ApplicationConfig < Struct.new(
  :f_port,
  :type,
  :destination_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Application type, which can be specified to obtain real-time position information of your LoRaWAN device.



111
112
113
114
115
116
117
# File 'lib/aws-sdk-iotwireless/types.rb', line 111

class ApplicationConfig < Struct.new(
  :f_port,
  :type,
  :destination_name)
  SENSITIVE = []
  include Aws::Structure
end