Class: Aws::IoTWireless::Types::CreateWirelessGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_token ⇒ String

Each resource must have a unique client request token. The client token is used to implement idempotency. It ensures that the request completes no more than one time. If you retry a request with the same token and the same parameters, the request will complete successfully. However, if you try to create a new resource using the same token but different parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. For more information about idempotency, see Ensuring idempotency in Amazon EC2 API requests.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/aws-sdk-iotwireless/types.rb', line 1108

class CreateWirelessGatewayRequest < Struct.new(
  :name,
  :description,
  :lo_ra_wan,
  :tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the new resource.

Returns:

  • (String)


1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/aws-sdk-iotwireless/types.rb', line 1108

class CreateWirelessGatewayRequest < Struct.new(
  :name,
  :description,
  :lo_ra_wan,
  :tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wan ⇒ Types::LoRaWANGateway

The gateway configuration information to use to create the wireless gateway.



1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/aws-sdk-iotwireless/types.rb', line 1108

class CreateWirelessGatewayRequest < Struct.new(
  :name,
  :description,
  :lo_ra_wan,
  :tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the new resource.

The following special characters aren't accepted: <>^#~$

Returns:

  • (String)


1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/aws-sdk-iotwireless/types.rb', line 1108

class CreateWirelessGatewayRequest < Struct.new(
  :name,
  :description,
  :lo_ra_wan,
  :tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tags to attach to the new wireless gateway. Tags are metadata that you can use to manage a resource.

Returns:



1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/aws-sdk-iotwireless/types.rb', line 1108

class CreateWirelessGatewayRequest < Struct.new(
  :name,
  :description,
  :lo_ra_wan,
  :tags,
  :client_request_token)
  SENSITIVE = []
  include Aws::Structure
end