Class: Aws::IoTWireless::Types::CreateWirelessGatewayTaskDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::CreateWirelessGatewayTaskDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_create_tasks ⇒ Boolean
Whether to automatically create tasks using this task definition for all gateways with the specified current version.
-
#client_request_token ⇒ String
Each resource must have a unique client request token.
-
#name ⇒ String
The name of the new resource.
-
#tags ⇒ Array<Types::Tag>
The tags to attach to the specified resource.
-
#update ⇒ Types::UpdateWirelessGatewayTaskCreate
Information about the gateways to update.
Instance Attribute Details
#auto_create_tasks ⇒ Boolean
Whether to automatically create tasks using this task definition for all gateways with the specified current version. If false, the task must me created by calling CreateWirelessGatewayTask.
1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1133 class CreateWirelessGatewayTaskDefinitionRequest < Struct.new( :auto_create_tasks, :name, :update, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
Each resource must have a unique client request token. The client token is used to implement idempotency. It ensures that the request completes no more than one time. If you retry a request with the same token and the same parameters, the request will complete successfully. However, if you try to create a new resource using the same token but different parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. For more information about idempotency, see [Ensuring idempotency in Amazon EC2 API requests].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1133 class CreateWirelessGatewayTaskDefinitionRequest < Struct.new( :auto_create_tasks, :name, :update, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new resource.
1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1133 class CreateWirelessGatewayTaskDefinitionRequest < Struct.new( :auto_create_tasks, :name, :update, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to attach to the specified resource. Tags are metadata that you can use to manage a resource.
1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1133 class CreateWirelessGatewayTaskDefinitionRequest < Struct.new( :auto_create_tasks, :name, :update, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#update ⇒ Types::UpdateWirelessGatewayTaskCreate
Information about the gateways to update.
1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1133 class CreateWirelessGatewayTaskDefinitionRequest < Struct.new( :auto_create_tasks, :name, :update, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |