Class: Aws::IoTWireless::Types::DeleteQueuedMessagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::DeleteQueuedMessagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of a given wireless device for which downlink messages will be deleted.
-
#message_id ⇒ String
If message ID is ‘“*”`, it cleares the entire downlink queue for a given device, specified by the wireless device ID.
-
#wireless_device_type ⇒ String
The wireless device type, which can be either Sidewalk or LoRaWAN.
Instance Attribute Details
#id ⇒ String
The ID of a given wireless device for which downlink messages will be deleted.
1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1320 class DeleteQueuedMessagesRequest < Struct.new( :id, :message_id, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |
#message_id ⇒ String
If message ID is ‘“*”`, it cleares the entire downlink queue for a given device, specified by the wireless device ID. Otherwise, the downlink message with the specified message ID will be deleted.
1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1320 class DeleteQueuedMessagesRequest < Struct.new( :id, :message_id, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |
#wireless_device_type ⇒ String
The wireless device type, which can be either Sidewalk or LoRaWAN.
1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1320 class DeleteQueuedMessagesRequest < Struct.new( :id, :message_id, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |