Class: Aws::IoTWireless::Types::EventConfigurationItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Event configuration object for a single resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#events ⇒ Types::EventNotificationItemConfigurations

Object of all event configurations and the status of the event topics.



1718
1719
1720
1721
1722
1723
1724
1725
# File 'lib/aws-sdk-iotwireless/types.rb', line 1718

class EventConfigurationItem < Struct.new(
  :identifier,
  :identifier_type,
  :partner_type,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#identifier ⇒ String

Resource identifier opted in for event messaging.



1718
1719
1720
1721
1722
1723
1724
1725
# File 'lib/aws-sdk-iotwireless/types.rb', line 1718

class EventConfigurationItem < Struct.new(
  :identifier,
  :identifier_type,
  :partner_type,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#identifier_type ⇒ String

Identifier type of the particular resource identifier for event configuration.



1718
1719
1720
1721
1722
1723
1724
1725
# File 'lib/aws-sdk-iotwireless/types.rb', line 1718

class EventConfigurationItem < Struct.new(
  :identifier,
  :identifier_type,
  :partner_type,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#partner_type ⇒ String

Partner type of the resource if the identifier type is PartnerAccountId.



1718
1719
1720
1721
1722
1723
1724
1725
# File 'lib/aws-sdk-iotwireless/types.rb', line 1718

class EventConfigurationItem < Struct.new(
  :identifier,
  :identifier_type,
  :partner_type,
  :events)
  SENSITIVE = []
  include Aws::Structure
end