Class: Aws::IoTWireless::Types::FuotaTaskLogOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The log options for FUOTA tasks and can be used to set log levels for a specific type of FUOTA task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::FuotaTaskEventLogOption>

The list of FUOTA task event log options.



1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-iotwireless/types.rb', line 1828

class FuotaTaskLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level for a log message. The log levels can be disabled, or set to ERROR to display less verbose logs containing only error information, or to INFO for more detailed logs.



1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-iotwireless/types.rb', line 1828

class FuotaTaskLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The FUOTA task type.



1828
1829
1830
1831
1832
1833
1834
# File 'lib/aws-sdk-iotwireless/types.rb', line 1828

class FuotaTaskLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end