Class: Aws::IoTWireless::Types::GatewayListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Gateway list item object that specifies the frequency and list of gateways for which the downlink message should be sent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The frequency to use for the gateways when sending a downlink message to the wireless device.

Returns:

  • (Integer)


1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotwireless/types.rb', line 1881

class GatewayListItem < Struct.new(
  :gateway_id,
  :downlink_frequency)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_id ⇒ String

The ID of the wireless gateways that you want to add to the list of gateways when sending downlink messages.

Returns:

  • (String)


1881
1882
1883
1884
1885
1886
# File 'lib/aws-sdk-iotwireless/types.rb', line 1881

class GatewayListItem < Struct.new(
  :gateway_id,
  :downlink_frequency)
  SENSITIVE = []
  include Aws::Structure
end