Class: Aws::IoTWireless::Types::GetFuotaTaskResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The arn of a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

Created at timestamp for the resource.

Returns:

  • (Time)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the new resource.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#descriptorString

The descriptor is the metadata about the file that is transferred to the device using FUOTA, such as the software version. It is a binary field encoded in base64.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#firmware_update_imageString

The S3 URI points to a firmware update image that is to be used with a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#firmware_update_roleString

The firmware update role that is to be used with a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#fragment_interval_msInteger

The interval for sending fragments in milliseconds, rounded to the nearest second.

<note markdown=“1”> This interval only determines the timing for when the Cloud sends down the fragments to yor device. There can be a delay for when your device will receive these fragments. This delay depends on the device’s class and the communication delay with the cloud.

</note>

Returns:

  • (Integer)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#fragment_size_bytesInteger

The size of each fragment in bytes. This parameter is supported only for FUOTA tasks with multicast groups.

Returns:

  • (Integer)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wanTypes::LoRaWANFuotaTaskGetInfo

The LoRaWAN information returned from getting a FUOTA task.



2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#redundancy_percentInteger

The percentage of the added fragments that are redundant. For example, if the size of the firmware image file is 100 bytes and the fragment size is 10 bytes, with ‘RedundancyPercent` set to 50(%), the final number of encoded fragments is (100 / 10) + (100 / 10 * 50%) = 15.

Returns:

  • (Integer)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of a FUOTA task.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/aws-sdk-iotwireless/types.rb', line 2068

class GetFuotaTaskResponse < Struct.new(
  :arn,
  :id,
  :status,
  :name,
  :description,
  :lo_ra_wan,
  :firmware_update_image,
  :firmware_update_role,
  :created_at,
  :redundancy_percent,
  :fragment_size_bytes,
  :fragment_interval_ms,
  :descriptor)
  SENSITIVE = []
  include Aws::Structure
end