Class: Aws::IoTWireless::Types::GetNetworkAnalyzerConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name of the new resource.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the new resource.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_groups ⇒ Array<String>

List of multicast group resources that have been added to the network analyzer configuration.

Returns:

  • (Array<String>)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Name of the network analyzer configuration.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#trace_content ⇒ Types::TraceContent

Trace content for your wireless devices, gateways, and multicast groups.

Returns:



2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_devices ⇒ Array<String>

List of wireless device resources that have been added to the network analyzer configuration.

Returns:

  • (Array<String>)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_gateways ⇒ Array<String>

List of wireless gateway resources that have been added to the network analyzer configuration.

Returns:

  • (Array<String>)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-iotwireless/types.rb', line 2284

class GetNetworkAnalyzerConfigurationResponse < Struct.new(
  :trace_content,
  :wireless_devices,
  :wireless_gateways,
  :description,
  :arn,
  :name,
  :multicast_groups)
  SENSITIVE = []
  include Aws::Structure
end