Class: Aws::IoTWireless::Types::GetPositionEstimateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#geo_json_payloadString

The position information of the resource, displayed as a JSON payload. The payload is of type blob and uses the GeoJSON format, which a format that's used to encode geographic data structures. A sample payload contains the timestamp information, the WGS84 coordinates of the location, and the accuracy and confidence level. For more information and examples, see Resolve device location (console).

Returns:

  • (String)


2418
2419
2420
2421
2422
# File 'lib/aws-sdk-iotwireless/types.rb', line 2418

class GetPositionEstimateResponse < Struct.new(
  :geo_json_payload)
  SENSITIVE = []
  include Aws::Structure
end