Class: Aws::IoTWireless::Types::GetPositionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accuracy ⇒ Types::Accuracy

The accuracy of the estimated position in meters. An empty value indicates that no position data is available. A value of ‘0.0’ value indicates that position data is available. This data corresponds to the position information that you specified instead of the position computed by solver.

Returns:



2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#position ⇒ Array<Float>

The position information of the resource.

Returns:

  • (Array<Float>)


2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#solver_provider ⇒ String

The vendor of the positioning solver.

Returns:

  • (String)


2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#solver_type ⇒ String

The type of solver used to identify the position of the resource.

Returns:

  • (String)


2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#solver_version ⇒ String

The version of the positioning solver.

Returns:

  • (String)


2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#timestamp ⇒ String

The timestamp at which the device's position was determined.

Returns:

  • (String)


2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-iotwireless/types.rb', line 2478

class GetPositionResponse < Struct.new(
  :position,
  :accuracy,
  :solver_type,
  :solver_provider,
  :solver_version,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end