Class: Aws::IoTWireless::Types::GetResourcePositionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::GetResourcePositionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_identifier ⇒ String
The identifier of the resource for which position information is retrieved.
-
#resource_type ⇒ String
The type of resource for which position information is retrieved, which can be a wireless device or a wireless gateway.
Instance Attribute Details
#resource_identifier ⇒ String
The identifier of the resource for which position information is retrieved. It can be the wireless device ID or the wireless gateway ID, depending on the resource type.
2554 2555 2556 2557 2558 2559 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2554 class GetResourcePositionRequest < Struct.new( :resource_identifier, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource for which position information is retrieved, which can be a wireless device or a wireless gateway.
2554 2555 2556 2557 2558 2559 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2554 class GetResourcePositionRequest < Struct.new( :resource_identifier, :resource_type) SENSITIVE = [] include Aws::Structure end |