Class: Aws::IoTWireless::Types::GetServiceEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#service_type ⇒ String

The service type for which to get endpoint information about. Can be CUPS for the Configuration and Update Server endpoint, or LNS for the LoRaWAN Network Server endpoint.

Returns:

  • (String)


2611
2612
2613
2614
2615
# File 'lib/aws-sdk-iotwireless/types.rb', line 2611

class GetServiceEndpointRequest < Struct.new(
  :service_type)
  SENSITIVE = []
  include Aws::Structure
end