Class: Aws::IoTWireless::Types::GetWirelessDeviceImportTaskResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN (Amazon Resource Name) of the import task.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

The time at which the import task was created.

Returns:

  • (Time)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_name ⇒ String

The name of the destination that's assigned to the wireless devices in the import task.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#failed_imported_device_count ⇒ Integer

The number of devices in the import task that failed to onboard to the import task.

Returns:

  • (Integer)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The identifier of the import task for which information is retrieved.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#initialized_imported_device_count ⇒ Integer

The number of devices in the import task that are waiting for the control log to start processing.

Returns:

  • (Integer)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#onboarded_imported_device_count ⇒ Integer

The number of devices in the import task that have been onboarded to the import task.

Returns:

  • (Integer)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#pending_imported_device_count ⇒ Integer

The number of devices in the import task that are waiting in the import task queue to be onboarded.

Returns:

  • (Integer)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ String

The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkGetStartImportInfo

The Sidewalk-related information about an import task.



2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The import task status.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#status_reason ⇒ String

The reason for the provided status information, such as a validation error that causes the import task to fail.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
# File 'lib/aws-sdk-iotwireless/types.rb', line 2739

class GetWirelessDeviceImportTaskResponse < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end