Class: Aws::IoTWireless::Types::GetWirelessDeviceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name of the resource.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the resource.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#destination_name ⇒ String

The name of the destination to which the device is assigned.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the wireless device.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wan ⇒ Types::LoRaWANDevice

Information about the wireless device.



2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the resource.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ String

The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkDevice

Sidewalk device object.



2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#thing_arn ⇒ String

The ARN of the thing associated with the wireless device.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#thing_name ⇒ String

The name of the thing associated with the wireless device. The value is empty if a thing isn't associated with the device.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The wireless device type.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
# File 'lib/aws-sdk-iotwireless/types.rb', line 2817

class GetWirelessDeviceResponse < Struct.new(
  :type,
  :name,
  :description,
  :destination_name,
  :id,
  :arn,
  :thing_name,
  :thing_arn,
  :lo_ra_wan,
  :sidewalk,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end