Class: Aws::IoTWireless::Types::GetWirelessGatewayResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name of the resource.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the resource.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the wireless gateway.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wanTypes::LoRaWANGateway

Information about the wireless gateway.



2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#thing_arnString

The ARN of the thing associated with the wireless gateway.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end

#thing_nameString

The name of the thing associated with the wireless gateway. The value is empty if a thing isn’t associated with the gateway.

Returns:

  • (String)


2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
# File 'lib/aws-sdk-iotwireless/types.rb', line 2935

class GetWirelessGatewayResponse < Struct.new(
  :name,
  :id,
  :description,
  :lo_ra_wan,
  :arn,
  :thing_name,
  :thing_arn)
  SENSITIVE = []
  include Aws::Structure
end