Class: Aws::IoTWireless::Types::GetWirelessGatewayTaskDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::GetWirelessGatewayTaskDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name of the resource.
-
#auto_create_tasks ⇒ Boolean
Whether to automatically create tasks using this task definition for all gateways with the specified current version.
-
#name ⇒ String
The name of the resource.
-
#update ⇒ Types::UpdateWirelessGatewayTaskCreate
Information about the gateways to update.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name of the resource.
3026 3027 3028 3029 3030 3031 3032 3033 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3026 class GetWirelessGatewayTaskDefinitionResponse < Struct.new( :auto_create_tasks, :name, :update, :arn) SENSITIVE = [] include Aws::Structure end |
#auto_create_tasks ⇒ Boolean
Whether to automatically create tasks using this task definition for
all gateways with the specified current version. If false, the
task must me created by calling CreateWirelessGatewayTask.
3026 3027 3028 3029 3030 3031 3032 3033 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3026 class GetWirelessGatewayTaskDefinitionResponse < Struct.new( :auto_create_tasks, :name, :update, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource.
3026 3027 3028 3029 3030 3031 3032 3033 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3026 class GetWirelessGatewayTaskDefinitionResponse < Struct.new( :auto_create_tasks, :name, :update, :arn) SENSITIVE = [] include Aws::Structure end |
#update ⇒ Types::UpdateWirelessGatewayTaskCreate
Information about the gateways to update.
3026 3027 3028 3029 3030 3031 3032 3033 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3026 class GetWirelessGatewayTaskDefinitionResponse < Struct.new( :auto_create_tasks, :name, :update, :arn) SENSITIVE = [] include Aws::Structure end |