Class: Aws::IoTWireless::Types::ListDestinationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_list ⇒ Array<Types::Destinations>

The list of destinations.

Returns:



3441
3442
3443
3444
3445
3446
# File 'lib/aws-sdk-iotwireless/types.rb', line 3441

class ListDestinationsResponse < Struct.new(
  :next_token,
  :destination_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


3441
3442
3443
3444
3445
3446
# File 'lib/aws-sdk-iotwireless/types.rb', line 3441

class ListDestinationsResponse < Struct.new(
  :next_token,
  :destination_list)
  SENSITIVE = []
  include Aws::Structure
end