Class: Aws::IoTWireless::Types::ListDeviceProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListDeviceProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_profile_list ⇒ Array<Types::DeviceProfile>
The list of device profiles.
-
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
Instance Attribute Details
#device_profile_list ⇒ Array<Types::DeviceProfile>
The list of device profiles.
3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3369 class ListDeviceProfilesResponse < Struct.new( :next_token, :device_profile_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3369 class ListDeviceProfilesResponse < Struct.new( :next_token, :device_profile_list) SENSITIVE = [] include Aws::Structure end |