Class: Aws::IoTWireless::Types::ListFuotaTasksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fuota_task_list ⇒ Array<Types::FuotaTask>

Lists the FUOTA tasks registered to your AWS account.

Returns:



3616
3617
3618
3619
3620
3621
# File 'lib/aws-sdk-iotwireless/types.rb', line 3616

class ListFuotaTasksResponse < Struct.new(
  :next_token,
  :fuota_task_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3616
3617
3618
3619
3620
3621
# File 'lib/aws-sdk-iotwireless/types.rb', line 3616

class ListFuotaTasksResponse < Struct.new(
  :next_token,
  :fuota_task_list)
  SENSITIVE = []
  include Aws::Structure
end