Class: Aws::IoTWireless::Types::ListMulticastGroupsByFuotaTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ String

The ID of a FUOTA task.

Returns:

  • (String)


3637
3638
3639
3640
3641
3642
3643
# File 'lib/aws-sdk-iotwireless/types.rb', line 3637

class ListMulticastGroupsByFuotaTaskRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in this operation.

Returns:

  • (Integer)


3637
3638
3639
3640
3641
3642
3643
# File 'lib/aws-sdk-iotwireless/types.rb', line 3637

class ListMulticastGroupsByFuotaTaskRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3637
3638
3639
3640
3641
3642
3643
# File 'lib/aws-sdk-iotwireless/types.rb', line 3637

class ListMulticastGroupsByFuotaTaskRequest < Struct.new(
  :id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end