Class: Aws::IoTWireless::Types::ListMulticastGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListMulticastGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#multicast_group_list ⇒ Array<Types::MulticastGroup>
List of multicast groups.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results.
Instance Attribute Details
#multicast_group_list ⇒ Array<Types::MulticastGroup>
List of multicast groups.
3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3578 class ListMulticastGroupsResponse < Struct.new( :next_token, :multicast_group_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
3578 3579 3580 3581 3582 3583 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3578 class ListMulticastGroupsResponse < Struct.new( :next_token, :multicast_group_list) SENSITIVE = [] include Aws::Structure end |