Class: Aws::IoTWireless::Types::ListPartnerAccountsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListPartnerAccountsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
-
#sidewalk ⇒ Array<Types::SidewalkAccountInfoWithFingerprint>
The Sidewalk account credentials.
Instance Attribute Details
#next_token ⇒ String
The token to use to get the next set of results, or null if there are no additional results.
3644 3645 3646 3647 3648 3649 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3644 class ListPartnerAccountsResponse < Struct.new( :next_token, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Array<Types::SidewalkAccountInfoWithFingerprint>
The Sidewalk account credentials.
3644 3645 3646 3647 3648 3649 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3644 class ListPartnerAccountsResponse < Struct.new( :next_token, :sidewalk) SENSITIVE = [] include Aws::Structure end |