Class: Aws::IoTWireless::Types::ListPositionConfigurationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


3793
3794
3795
3796
3797
3798
# File 'lib/aws-sdk-iotwireless/types.rb', line 3793

class ListPositionConfigurationsResponse < Struct.new(
  :position_configuration_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#position_configuration_list ⇒ Array<Types::PositionConfigurationItem>

A list of position configurations.



3793
3794
3795
3796
3797
3798
# File 'lib/aws-sdk-iotwireless/types.rb', line 3793

class ListPositionConfigurationsResponse < Struct.new(
  :position_configuration_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end