Class: Aws::IoTWireless::Types::ListQueuedMessagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ String

The ID of a given wireless device which the downlink message packets are being sent.

Returns:

  • (String)


3819
3820
3821
3822
3823
3824
3825
3826
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819

class ListQueuedMessagesRequest < Struct.new(
  :id,
  :next_token,
  :max_results,
  :wireless_device_type)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in this operation.

Returns:

  • (Integer)


3819
3820
3821
3822
3823
3824
3825
3826
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819

class ListQueuedMessagesRequest < Struct.new(
  :id,
  :next_token,
  :max_results,
  :wireless_device_type)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3819
3820
3821
3822
3823
3824
3825
3826
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819

class ListQueuedMessagesRequest < Struct.new(
  :id,
  :next_token,
  :max_results,
  :wireless_device_type)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_device_type ⇒ String

The wireless device type, whic can be either Sidewalk or LoRaWAN.

Returns:

  • (String)


3819
3820
3821
3822
3823
3824
3825
3826
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819

class ListQueuedMessagesRequest < Struct.new(
  :id,
  :next_token,
  :max_results,
  :wireless_device_type)
  SENSITIVE = []
  include Aws::Structure
end