Class: Aws::IoTWireless::Types::ListQueuedMessagesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The messages in the downlink queue.

Returns:



3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-iotwireless/types.rb', line 3838

class ListQueuedMessagesResponse < Struct.new(
  :next_token,
  :downlink_queue_messages_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-iotwireless/types.rb', line 3838

class ListQueuedMessagesResponse < Struct.new(
  :next_token,
  :downlink_queue_messages_list)
  SENSITIVE = []
  include Aws::Structure
end