Class: Aws::IoTWireless::Types::ListServiceProfilesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


3871
3872
3873
3874
3875
3876
# File 'lib/aws-sdk-iotwireless/types.rb', line 3871

class ListServiceProfilesResponse < Struct.new(
  :next_token,
  :service_profile_list)
  SENSITIVE = []
  include Aws::Structure
end

#service_profile_list ⇒ Array<Types::ServiceProfile>

The list of service profiles.

Returns:



3871
3872
3873
3874
3875
3876
# File 'lib/aws-sdk-iotwireless/types.rb', line 3871

class ListServiceProfilesResponse < Struct.new(
  :next_token,
  :service_profile_list)
  SENSITIVE = []
  include Aws::Structure
end