Class: Aws::IoTWireless::Types::ListWirelessDevicesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_name ⇒ String

A filter to list only the wireless devices that use as uplink destination.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#device_profile_id ⇒ String

A filter to list only the wireless devices that use this device profile.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#fuota_task_id ⇒ String

The ID of a FUOTA task.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return in this operation.

Returns:

  • (Integer)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_group_id ⇒ String

The ID of the multicast group.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#service_profile_id ⇒ String

A filter to list only the wireless devices that use this service profile.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_device_type ⇒ String

A filter to list only the wireless devices that use this wireless device type.

Returns:

  • (String)


3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-iotwireless/types.rb', line 3971

class ListWirelessDevicesRequest < Struct.new(
  :max_results,
  :next_token,
  :destination_name,
  :device_profile_id,
  :service_profile_id,
  :wireless_device_type,
  :fuota_task_id,
  :multicast_group_id)
  SENSITIVE = []
  include Aws::Structure
end