Class: Aws::IoTWireless::Types::ListWirelessDevicesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


3993
3994
3995
3996
3997
3998
# File 'lib/aws-sdk-iotwireless/types.rb', line 3993

class ListWirelessDevicesResponse < Struct.new(
  :next_token,
  :wireless_device_list)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_device_list ⇒ Array<Types::WirelessDeviceStatistics>

The ID of the wireless device.



3993
3994
3995
3996
3997
3998
# File 'lib/aws-sdk-iotwireless/types.rb', line 3993

class ListWirelessDevicesResponse < Struct.new(
  :next_token,
  :wireless_device_list)
  SENSITIVE = []
  include Aws::Structure
end