Class: Aws::IoTWireless::Types::ListWirelessGatewayTaskDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListWirelessGatewayTaskDefinitionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#task_definition_type ⇒ String
A filter to list only the wireless gateway task definitions that use this task definition type.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in this operation.
4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4015 class ListWirelessGatewayTaskDefinitionsRequest < Struct.new( :max_results, :next_token, :task_definition_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4015 class ListWirelessGatewayTaskDefinitionsRequest < Struct.new( :max_results, :next_token, :task_definition_type) SENSITIVE = [] include Aws::Structure end |
#task_definition_type ⇒ String
A filter to list only the wireless gateway task definitions that use this task definition type.
4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4015 class ListWirelessGatewayTaskDefinitionsRequest < Struct.new( :max_results, :next_token, :task_definition_type) SENSITIVE = [] include Aws::Structure end |