Class: Aws::IoTWireless::Types::ListWirelessGatewayTaskDefinitionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


4032
4033
4034
4035
4036
4037
# File 'lib/aws-sdk-iotwireless/types.rb', line 4032

class ListWirelessGatewayTaskDefinitionsResponse < Struct.new(
  :next_token,
  :task_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#task_definitions ⇒ Array<Types::UpdateWirelessGatewayTaskEntry>

The list of task definitions.



4032
4033
4034
4035
4036
4037
# File 'lib/aws-sdk-iotwireless/types.rb', line 4032

class ListWirelessGatewayTaskDefinitionsResponse < Struct.new(
  :next_token,
  :task_definitions)
  SENSITIVE = []
  include Aws::Structure
end