Class: Aws::IoTWireless::Types::ListWirelessGatewaysResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to use to get the next set of results, or null if there are no additional results.

Returns:

  • (String)


4065
4066
4067
4068
4069
4070
# File 'lib/aws-sdk-iotwireless/types.rb', line 4065

class ListWirelessGatewaysResponse < Struct.new(
  :next_token,
  :wireless_gateway_list)
  SENSITIVE = []
  include Aws::Structure
end

#wireless_gateway_list ⇒ Array<Types::WirelessGatewayStatistics>

The ID of the wireless gateway.



4065
4066
4067
4068
4069
4070
# File 'lib/aws-sdk-iotwireless/types.rb', line 4065

class ListWirelessGatewaysResponse < Struct.new(
  :next_token,
  :wireless_gateway_list)
  SENSITIVE = []
  include Aws::Structure
end