Class: Aws::IoTWireless::Types::LoRaWANDeviceProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::LoRaWANDeviceProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
LoRaWANDeviceProfile object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#class_b_timeout ⇒ Integer
The ClassBTimeout value.
-
#class_c_timeout ⇒ Integer
The ClassCTimeout value.
-
#factory_preset_freqs_list ⇒ Array<Integer>
The list of values that make up the FactoryPresetFreqs value.
-
#mac_version ⇒ String
The MAC version (such as OTAA 1.1 or OTAA 1.0.3) to use with this device profile.
-
#max_duty_cycle ⇒ Integer
The MaxDutyCycle value.
-
#max_eirp ⇒ Integer
The MaxEIRP value.
-
#ping_slot_dr ⇒ Integer
The PingSlotDR value.
-
#ping_slot_freq ⇒ Integer
The PingSlotFreq value.
-
#ping_slot_period ⇒ Integer
The PingSlotPeriod value.
-
#reg_params_revision ⇒ String
The version of regional parameters.
-
#rf_region ⇒ String
The frequency band (RFRegion) value.
-
#rx_data_rate_2 ⇒ Integer
The RXDataRate2 value.
-
#rx_delay_1 ⇒ Integer
The RXDelay1 value.
-
#rx_dr_offset_1 ⇒ Integer
The RXDROffset1 value.
-
#rx_freq_2 ⇒ Integer
The RXFreq2 value.
-
#supports_32_bit_f_cnt ⇒ Boolean
The Supports32BitFCnt value.
-
#supports_class_b ⇒ Boolean
The SupportsClassB value.
-
#supports_class_c ⇒ Boolean
The SupportsClassC value.
-
#supports_join ⇒ Boolean
The SupportsJoin value.
Instance Attribute Details
#class_b_timeout ⇒ Integer
The ClassBTimeout value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#class_c_timeout ⇒ Integer
The ClassCTimeout value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#factory_preset_freqs_list ⇒ Array<Integer>
The list of values that make up the FactoryPresetFreqs value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#mac_version ⇒ String
The MAC version (such as OTAA 1.1 or OTAA 1.0.3) to use with this device profile.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#max_duty_cycle ⇒ Integer
The MaxDutyCycle value. It ranges from 0 to 15.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#max_eirp ⇒ Integer
The MaxEIRP value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#ping_slot_dr ⇒ Integer
The PingSlotDR value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#ping_slot_freq ⇒ Integer
The PingSlotFreq value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#ping_slot_period ⇒ Integer
The PingSlotPeriod value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#reg_params_revision ⇒ String
The version of regional parameters.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#rf_region ⇒ String
The frequency band (RFRegion) value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#rx_data_rate_2 ⇒ Integer
The RXDataRate2 value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#rx_delay_1 ⇒ Integer
The RXDelay1 value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#rx_dr_offset_1 ⇒ Integer
The RXDROffset1 value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#rx_freq_2 ⇒ Integer
The RXFreq2 value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#supports_32_bit_f_cnt ⇒ Boolean
The Supports32BitFCnt value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#supports_class_b ⇒ Boolean
The SupportsClassB value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#supports_class_c ⇒ Boolean
The SupportsClassC value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |
#supports_join ⇒ Boolean
The SupportsJoin value.
4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4194 class LoRaWANDeviceProfile < Struct.new( :supports_class_b, :class_b_timeout, :ping_slot_period, :ping_slot_dr, :ping_slot_freq, :supports_class_c, :class_c_timeout, :mac_version, :reg_params_revision, :rx_delay_1, :rx_dr_offset_1, :rx_data_rate_2, :rx_freq_2, :factory_preset_freqs_list, :max_eirp, :max_duty_cycle, :rf_region, :supports_join, :supports_32_bit_f_cnt) SENSITIVE = [] include Aws::Structure end |