Class: Aws::IoTWireless::Types::LoRaWANMulticast
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::LoRaWANMulticast
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The LoRaWAN information that is to be used with the multicast group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_session_parameters ⇒ Types::DefaultSessionParametersMulticast
The default session parameters for the multicast group.
-
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
-
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages.
-
#rf_region ⇒ String
Supported RfRegions.
Instance Attribute Details
#default_session_parameters ⇒ Types::DefaultSessionParametersMulticast
The default session parameters for the multicast group.
4539 4540 4541 4542 4543 4544 4545 4546 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4539 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
4539 4540 4541 4542 4543 4544 4545 4546 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4539 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages. The multicast message will be sent to each gateway in the list, with the transmission interval as the time interval between each message.
4539 4540 4541 4542 4543 4544 4545 4546 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4539 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#rf_region ⇒ String
Supported RfRegions
4539 4540 4541 4542 4543 4544 4545 4546 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4539 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |