Class: Aws::IoTWireless::Types::LoRaWANMulticastGet
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::LoRaWANMulticastGet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The LoRaWAN information that is to be returned from getting multicast group information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_session_parameters ⇒ Types::DefaultSessionParametersMulticast
The default session parameters for the multicast group.
-
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
-
#number_of_devices_in_group ⇒ Integer
Number of devices that are associated to the multicast group.
-
#number_of_devices_requested ⇒ Integer
Number of devices that are requested to be associated with the multicast group.
-
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages.
-
#rf_region ⇒ String
Supported RfRegions.
Instance Attribute Details
#default_session_parameters ⇒ Types::DefaultSessionParametersMulticast
The default session parameters for the multicast group.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#number_of_devices_in_group ⇒ Integer
Number of devices that are associated to the multicast group.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#number_of_devices_requested ⇒ Integer
Number of devices that are requested to be associated with the multicast group.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages. The multicast message will be sent to each gateway in the list, with the transmission interval as the time interval between each message.
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |
#rf_region ⇒ String
Supported RfRegions
4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4579 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways, :default_session_parameters) SENSITIVE = [] include Aws::Structure end |