Class: Aws::IoTWireless::Types::LoRaWANMulticastSession

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The LoRaWAN information used with the multicast session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dl_dr ⇒ Integer

Downlink data rate.

Returns:

  • (Integer)


4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-iotwireless/types.rb', line 4706

class LoRaWANMulticastSession < Struct.new(
  :dl_dr,
  :dl_freq,
  :session_start_time,
  :session_timeout,
  :ping_slot_period)
  SENSITIVE = []
  include Aws::Structure
end

#dl_freq ⇒ Integer

Downlink frequency.

Returns:

  • (Integer)


4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-iotwireless/types.rb', line 4706

class LoRaWANMulticastSession < Struct.new(
  :dl_dr,
  :dl_freq,
  :session_start_time,
  :session_timeout,
  :ping_slot_period)
  SENSITIVE = []
  include Aws::Structure
end

#ping_slot_period ⇒ Integer

The PingSlotPeriod value.

Returns:

  • (Integer)


4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-iotwireless/types.rb', line 4706

class LoRaWANMulticastSession < Struct.new(
  :dl_dr,
  :dl_freq,
  :session_start_time,
  :session_timeout,
  :ping_slot_period)
  SENSITIVE = []
  include Aws::Structure
end

#session_start_time ⇒ Time

Timestamp of when the multicast group session is to start.

Returns:

  • (Time)


4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-iotwireless/types.rb', line 4706

class LoRaWANMulticastSession < Struct.new(
  :dl_dr,
  :dl_freq,
  :session_start_time,
  :session_timeout,
  :ping_slot_period)
  SENSITIVE = []
  include Aws::Structure
end

#session_timeout ⇒ Integer

How long before a multicast group session is to timeout.

We recommend that you provide a timeout value that is a power-of-two (such as 64, 128, 256). If a non-power-of-two value is provided, it will automatically be rounded up to the next supported power-of-two within the allowed range.

Returns:

  • (Integer)


4706
4707
4708
4709
4710
4711
4712
4713
4714
# File 'lib/aws-sdk-iotwireless/types.rb', line 4706

class LoRaWANMulticastSession < Struct.new(
  :dl_dr,
  :dl_freq,
  :session_start_time,
  :session_timeout,
  :ping_slot_period)
  SENSITIVE = []
  include Aws::Structure
end