Class: Aws::IoTWireless::Types::LoRaWANPublicGatewayMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

LoRaWAN public gateway metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dl_allowed ⇒ Boolean

Boolean that indicates whether downlink is allowed using the network.

Returns:

  • (Boolean)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the gateways that are operated by the network provider.

Returns:

  • (String)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#provider_net_id ⇒ String

The ID of the LoRaWAN public network provider.

Returns:

  • (String)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#rf_region ⇒ String

The frequency band (RFRegion) value.

Returns:

  • (String)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#rssi ⇒ Float

The RSSI (received signal strength indicator) value.

Returns:

  • (Float)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#snr ⇒ Float

The SNR (signal to noise ratio) value.

Returns:

  • (Float)


4743
4744
4745
4746
4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-iotwireless/types.rb', line 4743

class LoRaWANPublicGatewayMetadata < Struct.new(
  :provider_net_id,
  :id,
  :rssi,
  :snr,
  :rf_region,
  :dl_allowed)
  SENSITIVE = []
  include Aws::Structure
end