Class: Aws::IoTWireless::Types::LoRaWANServiceProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

LoRaWANServiceProfile object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_gw_metadata ⇒ Boolean

The AddGWMetaData value.

Returns:

  • (Boolean)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#dr_max ⇒ Integer

The DrMax value.

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#dr_min ⇒ Integer

The DrMin value.

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#nb_trans_max ⇒ Integer

The maximum number of transmissions.

Default: 3

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#nb_trans_min ⇒ Integer

The minimum number of transmissions.

Default: 0

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#pr_allowed ⇒ Boolean

The PRAllowed value that describes whether passive roaming is allowed.

Returns:

  • (Boolean)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#ra_allowed ⇒ Boolean

The RAAllowed value that describes whether roaming activation is allowed.

Returns:

  • (Boolean)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#tx_power_index_max ⇒ Integer

The Transmit Power Index maximum.

Default: 15

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end

#tx_power_index_min ⇒ Integer

The Transmit Power Index minimum.

Default: 0

Returns:

  • (Integer)


4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
# File 'lib/aws-sdk-iotwireless/types.rb', line 4821

class LoRaWANServiceProfile < Struct.new(
  :add_gw_metadata,
  :dr_min,
  :dr_max,
  :pr_allowed,
  :ra_allowed,
  :tx_power_index_min,
  :tx_power_index_max,
  :nb_trans_min,
  :nb_trans_max)
  SENSITIVE = []
  include Aws::Structure
end