Class: Aws::IoTWireless::Types::LteObj

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

LTE object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eutran_cid ⇒ Integer

E-UTRAN (Evolved Universal Terrestrial Radio Access Network) Cell Global Identifier.

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_local_id ⇒ Types::LteLocalId

LTE local identification (local ID) information.

Returns:



5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_nmr ⇒ Array<Types::LteNmrObj>

LTE object for network measurement reports.

Returns:



5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_timing_advance ⇒ Integer

LTE timing advance.

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mcc ⇒ Integer

Mobile Country Code.

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mnc ⇒ Integer

Mobile Network Code.

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#nr_capable ⇒ Boolean

Parameter that determines whether the LTE object is capable of supporting NR (new radio).

Returns:

  • (Boolean)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rsrp ⇒ Integer

Signal power of the reference signal received, measured in dBm (decibel-milliwatts).

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rsrq ⇒ Float

Signal quality of the reference Signal received, measured in decibels (dB).

Returns:

  • (Float)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#tac ⇒ Integer

LTE tracking area code.

Returns:

  • (Integer)


5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
# File 'lib/aws-sdk-iotwireless/types.rb', line 5023

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end