Class: Aws::IoTWireless::Types::MetricQueryValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The aggregated values of the metric.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#avg ⇒ Float

The average of the values of all data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end

#max ⇒ Float

The maximum of the values of all the data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end

#min ⇒ Float

The minimum of the values of all data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end

#p90 ⇒ Float

The 90th percentile of the values of all data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end

#std ⇒ Float

The standard deviation of the values of all data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end

#sum ⇒ Float

The sum of the values of all data points collected during the aggregation period.

Returns:

  • (Float)


5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/aws-sdk-iotwireless/types.rb', line 5104

class MetricQueryValue < Struct.new(
  :min,
  :max,
  :sum,
  :avg,
  :std,
  :p90)
  SENSITIVE = []
  include Aws::Structure
end