Class: Aws::IoTWireless::Types::ParticipatingGateways

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Specify the list of gateways to which you want to send downlink data traffic when the wireless device is running in class B or class C mode.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Indicates whether to send the downlink message in sequential mode or concurrent mode, or to use only the chosen gateways from the previous uplink message transmission.

Returns:

  • (String)


5147
5148
5149
5150
5151
5152
5153
# File 'lib/aws-sdk-iotwireless/types.rb', line 5147

class ParticipatingGateways < Struct.new(
  :downlink_mode,
  :gateway_list,
  :transmission_interval)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_listArray<Types::GatewayListItem>

The list of gateways that you want to use for sending the downlink data traffic.

Returns:



5147
5148
5149
5150
5151
5152
5153
# File 'lib/aws-sdk-iotwireless/types.rb', line 5147

class ParticipatingGateways < Struct.new(
  :downlink_mode,
  :gateway_list,
  :transmission_interval)
  SENSITIVE = []
  include Aws::Structure
end

#transmission_intervalInteger

The duration of time for which AWS IoT Core for LoRaWAN will wait before transmitting the payload to the next gateway.

Returns:

  • (Integer)


5147
5148
5149
5150
5151
5152
5153
# File 'lib/aws-sdk-iotwireless/types.rb', line 5147

class ParticipatingGateways < Struct.new(
  :downlink_mode,
  :gateway_list,
  :transmission_interval)
  SENSITIVE = []
  include Aws::Structure
end