Class: Aws::IoTWireless::Types::PositionConfigurationItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The wrapper for a position configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination ⇒ String

The position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.

Returns:

  • (String)


5305
5306
5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-iotwireless/types.rb', line 5305

class PositionConfigurationItem < Struct.new(
  :resource_identifier,
  :resource_type,
  :solvers,
  :destination)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifier ⇒ String

Resource identifier for the position configuration.

Returns:

  • (String)


5305
5306
5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-iotwireless/types.rb', line 5305

class PositionConfigurationItem < Struct.new(
  :resource_identifier,
  :resource_type,
  :solvers,
  :destination)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

Resource type of the resource for the position configuration.

Returns:

  • (String)


5305
5306
5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-iotwireless/types.rb', line 5305

class PositionConfigurationItem < Struct.new(
  :resource_identifier,
  :resource_type,
  :solvers,
  :destination)
  SENSITIVE = []
  include Aws::Structure
end

#solvers ⇒ Types::PositionSolverDetails

The details of the positioning solver object used to compute the location.



5305
5306
5307
5308
5309
5310
5311
5312
# File 'lib/aws-sdk-iotwireless/types.rb', line 5305

class PositionConfigurationItem < Struct.new(
  :resource_identifier,
  :resource_type,
  :solvers,
  :destination)
  SENSITIVE = []
  include Aws::Structure
end