Class: Aws::IoTWireless::Types::PutPositionConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::PutPositionConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
The position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.
-
#resource_identifier ⇒ String
Resource identifier used to update the position configuration.
-
#resource_type ⇒ String
Resource type of the resource for which you want to update the position configuration.
-
#solvers ⇒ Types::PositionSolverConfigurations
The positioning solvers used to update the position configuration of the resource.
Instance Attribute Details
#destination ⇒ String
The position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.
5339 5340 5341 5342 5343 5344 5345 5346 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5339 class PutPositionConfigurationRequest < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
Resource identifier used to update the position configuration.
5339 5340 5341 5342 5343 5344 5345 5346 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5339 class PutPositionConfigurationRequest < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Resource type of the resource for which you want to update the position configuration.
5339 5340 5341 5342 5343 5344 5345 5346 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5339 class PutPositionConfigurationRequest < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#solvers ⇒ Types::PositionSolverConfigurations
The positioning solvers used to update the position configuration of the resource.
5339 5340 5341 5342 5343 5344 5345 5346 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5339 class PutPositionConfigurationRequest < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |