Class: Aws::IoTWireless::Types::PutResourceLogLevelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::PutResourceLogLevelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_level ⇒ String
The log level for a log message.
-
#resource_identifier ⇒ String
The identifier of the resource.
-
#resource_type ⇒ String
The type of the resource, which can be
WirelessDeviceorWirelessGateway.
Instance Attribute Details
#log_level ⇒ String
The log level for a log message. The log levels can be disabled, or set to ERROR to display less verbose logs containing only error information, or to INFO for more detailed logs.
5116 5117 5118 5119 5120 5121 5122 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5116 class PutResourceLogLevelRequest < Struct.new( :resource_identifier, :resource_type, :log_level) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
The identifier of the resource. For a Wireless Device, it is the wireless device ID. For a wireless gateway, it is the wireless gateway ID.
5116 5117 5118 5119 5120 5121 5122 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5116 class PutResourceLogLevelRequest < Struct.new( :resource_identifier, :resource_type, :log_level) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource, which can be WirelessDevice or WirelessGateway.
5116 5117 5118 5119 5120 5121 5122 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5116 class PutResourceLogLevelRequest < Struct.new( :resource_identifier, :resource_type, :log_level) SENSITIVE = [] include Aws::Structure end |