Class: Aws::IoTWireless::Types::SidewalkStartImportInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Information about an import task created for bulk provisioning.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#device_creation_file ⇒ String

The CSV file contained in an S3 bucket that's used for adding devices to an import task.

Returns:

  • (String)


6021
6022
6023
6024
6025
6026
6027
# File 'lib/aws-sdk-iotwireless/types.rb', line 6021

class SidewalkStartImportInfo < Struct.new(
  :device_creation_file,
  :role,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ Types::SidewalkPositioning

The Positioning object of the Sidewalk device.



6021
6022
6023
6024
6025
6026
6027
# File 'lib/aws-sdk-iotwireless/types.rb', line 6021

class SidewalkStartImportInfo < Struct.new(
  :device_creation_file,
  :role,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#role ⇒ String

The IAM role that allows AWS IoT Wireless to access the CSV file in the S3 bucket.

Returns:

  • (String)


6021
6022
6023
6024
6025
6026
6027
# File 'lib/aws-sdk-iotwireless/types.rb', line 6021

class SidewalkStartImportInfo < Struct.new(
  :device_creation_file,
  :role,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end