Class: Aws::IoTWireless::Types::StartBulkAssociateWirelessDeviceWithMulticastGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ String

The ID of the multicast group.

Returns:

  • (String)


6080
6081
6082
6083
6084
6085
6086
# File 'lib/aws-sdk-iotwireless/types.rb', line 6080

class StartBulkAssociateWirelessDeviceWithMulticastGroupRequest < Struct.new(
  :id,
  :query_string,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_string ⇒ String

Query string used to search for wireless devices as part of the bulk associate and disassociate process.

Returns:

  • (String)


6080
6081
6082
6083
6084
6085
6086
# File 'lib/aws-sdk-iotwireless/types.rb', line 6080

class StartBulkAssociateWirelessDeviceWithMulticastGroupRequest < Struct.new(
  :id,
  :query_string,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tag to attach to the specified resource. Tags are metadata that you can use to manage a resource.

Returns:



6080
6081
6082
6083
6084
6085
6086
# File 'lib/aws-sdk-iotwireless/types.rb', line 6080

class StartBulkAssociateWirelessDeviceWithMulticastGroupRequest < Struct.new(
  :id,
  :query_string,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end