Class: Aws::IoTWireless::Types::StartBulkDisassociateWirelessDeviceFromMulticastGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::StartBulkDisassociateWirelessDeviceFromMulticastGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the multicast group.
-
#query_string ⇒ String
Query string used to search for wireless devices as part of the bulk associate and disassociate process.
-
#tags ⇒ Array<Types::Tag>
The tag to attach to the specified resource.
Instance Attribute Details
#id ⇒ String
The ID of the multicast group.
6029 6030 6031 6032 6033 6034 6035 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6029 class StartBulkDisassociateWirelessDeviceFromMulticastGroupRequest < Struct.new( :id, :query_string, :tags) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
Query string used to search for wireless devices as part of the bulk associate and disassociate process.
6029 6030 6031 6032 6033 6034 6035 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6029 class StartBulkDisassociateWirelessDeviceFromMulticastGroupRequest < Struct.new( :id, :query_string, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag to attach to the specified resource. Tags are metadata that you can use to manage a resource.
6029 6030 6031 6032 6033 6034 6035 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6029 class StartBulkDisassociateWirelessDeviceFromMulticastGroupRequest < Struct.new( :id, :query_string, :tags) SENSITIVE = [] include Aws::Structure end |