Class: Aws::IoTWireless::Types::StartSingleWirelessDeviceImportTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_token ⇒ String

Each resource must have a unique client request token. The client token is used to implement idempotency. It ensures that the request completes no more than one time. If you retry a request with the same token and the same parameters, the request will complete successfully. However, if you try to create a new resource using the same token but different parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. For more information about idempotency, see Ensuring idempotency in Amazon EC2 API requests.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#destination_name ⇒ String

The name of the Sidewalk destination that describes the IoT rule to route messages from the device in the import task that will be onboarded to AWS IoT Wireless.

Returns:

  • (String)


6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#device_name ⇒ String

The name of the wireless device for which an import task is being started.

Returns:

  • (String)


6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ String

The integration status of the Device Location feature for Sidewalk devices.

Returns:

  • (String)


6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkSingleStartImportInfo

The Sidewalk-related parameters for importing a single wireless device.



6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tag to attach to the specified resource. Tags are metadata that you can use to manage a resource.

Returns:



6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
# File 'lib/aws-sdk-iotwireless/types.rb', line 6193

class StartSingleWirelessDeviceImportTaskRequest < Struct.new(
  :destination_name,
  :client_request_token,
  :device_name,
  :tags,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end