Class: Aws::IoTWireless::Types::StartWirelessDeviceImportTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::StartWirelessDeviceImportTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Each resource must have a unique client request token.
-
#destination_name ⇒ String
The name of the Sidewalk destination that describes the IoT rule to route messages from the devices in the import task that are onboarded to AWS IoT Wireless.
-
#positioning ⇒ String
The integration status of the Device Location feature for Sidewalk devices.
-
#sidewalk ⇒ Types::SidewalkStartImportInfo
The Sidewalk-related parameters for importing wireless devices that need to be provisioned in bulk.
-
#tags ⇒ Array<Types::Tag>
The tag to attach to the specified resource.
Instance Attribute Details
#client_request_token ⇒ String
Each resource must have a unique client request token. The client token is used to implement idempotency. It ensures that the request completes no more than one time. If you retry a request with the same token and the same parameters, the request will complete successfully. However, if you try to create a new resource using the same token but different parameters, an HTTP 409 conflict occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. For more information about idempotency, see [Ensuring idempotency in Amazon EC2 API requests].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/ec2/latest/devguide/ec2-api-idempotency.html
6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6157 class StartWirelessDeviceImportTaskRequest < Struct.new( :destination_name, :client_request_token, :tags, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The name of the Sidewalk destination that describes the IoT rule to route messages from the devices in the import task that are onboarded to AWS IoT Wireless.
6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6157 class StartWirelessDeviceImportTaskRequest < Struct.new( :destination_name, :client_request_token, :tags, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ String
The integration status of the Device Location feature for Sidewalk devices.
6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6157 class StartWirelessDeviceImportTaskRequest < Struct.new( :destination_name, :client_request_token, :tags, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Types::SidewalkStartImportInfo
The Sidewalk-related parameters for importing wireless devices that need to be provisioned in bulk.
6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6157 class StartWirelessDeviceImportTaskRequest < Struct.new( :destination_name, :client_request_token, :tags, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tag to attach to the specified resource. Tags are metadata that you can use to manage a resource.
6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6157 class StartWirelessDeviceImportTaskRequest < Struct.new( :destination_name, :client_request_token, :tags, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |