Class: Aws::IoTWireless::Types::TdscdmaObj

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

TD-SCDMA object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lacInteger

Location Area Code.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mccInteger

Mobile Country Code.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mncInteger

Mobile Network Code.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#path_lossInteger

Path loss, or path attenuation, is the reduction in power density of an electromagnetic wave as it propagates through space.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rscpInteger

Signal power of the received signal (Received Signal Code Power), measured in decibel-milliwatts (dBm).

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#tdscdma_local_idTypes::TdscdmaLocalId

TD-SCDMA local identification (local ID) information.



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#tdscdma_nmrArray<Types::TdscdmaNmrObj>

TD-SCDMA object for network measurement reports.

Returns:



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#tdscdma_timing_advanceInteger

TD-SCDMA Timing advance.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#utran_cidInteger

UTRAN (UMTS Terrestrial Radio Access Network) Cell Global Identifier.

Returns:

  • (Integer)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-iotwireless/types.rb', line 6451

class TdscdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :tdscdma_local_id,
  :tdscdma_timing_advance,
  :rscp,
  :path_loss,
  :tdscdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end