Class: Aws::IoTWireless::Types::UpdateFPorts
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::UpdateFPorts
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
Object for updating the FPorts information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#applications ⇒ Array<Types::ApplicationConfig>
LoRaWAN application, which can be used for geolocation by activating positioning.
-
#positioning ⇒ Types::Positioning
Positioning FPorts for the ClockSync, Stream, and GNSS functions.
Instance Attribute Details
#applications ⇒ Array<Types::ApplicationConfig>
LoRaWAN application, which can be used for geolocation by activating positioning.
6617 6618 6619 6620 6621 6622 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6617 class UpdateFPorts < Struct.new( :positioning, :applications) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ Types::Positioning
Positioning FPorts for the ClockSync, Stream, and GNSS functions.
6617 6618 6619 6620 6621 6622 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6617 class UpdateFPorts < Struct.new( :positioning, :applications) SENSITIVE = [] include Aws::Structure end |