Class: Aws::IoTWireless::Types::UpdateFuotaTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::UpdateFuotaTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the new resource.
-
#descriptor ⇒ String
The descriptor is the metadata about the file that is transferred to the device using FUOTA, such as the software version.
-
#firmware_update_image ⇒ String
The S3 URI points to a firmware update image that is to be used with a FUOTA task.
-
#firmware_update_role ⇒ String
The firmware update role that is to be used with a FUOTA task.
-
#fragment_interval_ms ⇒ Integer
The interval for sending fragments in milliseconds, rounded to the nearest second.
-
#fragment_size_bytes ⇒ Integer
The size of each fragment in bytes.
-
#id ⇒ String
The ID of a FUOTA task.
-
#lo_ra_wan ⇒ Types::LoRaWANFuotaTask
The LoRaWAN information used with a FUOTA task.
-
#name ⇒ String
The name of a FUOTA task.
-
#redundancy_percent ⇒ Integer
The percentage of the added fragments that are redundant.
Instance Attribute Details
#description ⇒ String
The description of the new resource.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#descriptor ⇒ String
The descriptor is the metadata about the file that is transferred to the device using FUOTA, such as the software version. It is a binary field encoded in base64.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#firmware_update_image ⇒ String
The S3 URI points to a firmware update image that is to be used with a FUOTA task.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#firmware_update_role ⇒ String
The firmware update role that is to be used with a FUOTA task.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#fragment_interval_ms ⇒ Integer
The interval for sending fragments in milliseconds, rounded to the nearest second.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#fragment_size_bytes ⇒ Integer
The size of each fragment in bytes. This parameter is supported only for FUOTA tasks with multicast groups.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of a FUOTA task.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#lo_ra_wan ⇒ Types::LoRaWANFuotaTask
The LoRaWAN information used with a FUOTA task.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of a FUOTA task.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |
#redundancy_percent ⇒ Integer
The percentage of the added fragments that are redundant. For
example, if the size of the firmware image file is 100 bytes and the
fragment size is 10 bytes, with RedundancyPercent set to 50(%),
the final number of encoded fragments is (100 / 10) + (100 / 10 *
50%) = 15.
6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6726 class UpdateFuotaTaskRequest < Struct.new( :id, :name, :description, :lo_ra_wan, :firmware_update_image, :firmware_update_role, :redundancy_percent, :fragment_size_bytes, :fragment_interval_ms, :descriptor) SENSITIVE = [] include Aws::Structure end |