Class: Aws::IoTWireless::Types::UpdateResourcePositionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::UpdateResourcePositionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#geo_json_payload ⇒ String
The position information of the resource, displayed as a JSON payload.
-
#resource_identifier ⇒ String
The identifier of the resource for which position information is updated.
-
#resource_type ⇒ String
The type of resource for which position information is updated, which can be a wireless device or a wireless gateway.
Instance Attribute Details
#geo_json_payload ⇒ String
The position information of the resource, displayed as a JSON payload. The payload uses the GeoJSON format, which a format that's used to encode geographic data structures. For more information, see GeoJSON.
6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6991 class UpdateResourcePositionRequest < Struct.new( :resource_identifier, :resource_type, :geo_json_payload) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
The identifier of the resource for which position information is updated. It can be the wireless device ID or the wireless gateway ID, depending on the resource type.
6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6991 class UpdateResourcePositionRequest < Struct.new( :resource_identifier, :resource_type, :geo_json_payload) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource for which position information is updated, which can be a wireless device or a wireless gateway.
6991 6992 6993 6994 6995 6996 6997 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 6991 class UpdateResourcePositionRequest < Struct.new( :resource_identifier, :resource_type, :geo_json_payload) SENSITIVE = [] include Aws::Structure end |