Class: Aws::IoTWireless::Types::UpdateWirelessDeviceImportTaskRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ String

The identifier of the import task to be updated.

Returns:

  • (String)


7084
7085
7086
7087
7088
7089
# File 'lib/aws-sdk-iotwireless/types.rb', line 7084

class UpdateWirelessDeviceImportTaskRequest < Struct.new(
  :id,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkUpdateImportInfo

The Sidewalk-related parameters of the import task to be updated.



7084
7085
7086
7087
7088
7089
# File 'lib/aws-sdk-iotwireless/types.rb', line 7084

class UpdateWirelessDeviceImportTaskRequest < Struct.new(
  :id,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end