Class: Aws::IoTWireless::Types::UpdateWirelessDeviceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A new description of the resource.

Returns:

  • (String)


7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#destination_name ⇒ String

The name of the new destination for the device.

Returns:

  • (String)


7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the resource to update.

Returns:

  • (String)


7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wan ⇒ Types::LoRaWANUpdateDevice

The updated wireless device's configuration.



7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The new name of the resource.

The following special characters aren't accepted: <>^#~$

Returns:

  • (String)


7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ String

The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.

Returns:

  • (String)


7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkUpdateWirelessDevice

The updated sidewalk properties.



7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
# File 'lib/aws-sdk-iotwireless/types.rb', line 7126

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end