Class: Aws::IoTWireless::Types::UpdateWirelessGatewayTaskCreate
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::UpdateWirelessGatewayTaskCreate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
UpdateWirelessGatewayTaskCreate object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lo_ra_wan ⇒ Types::LoRaWANUpdateGatewayTaskCreate
The properties that relate to the LoRaWAN wireless gateway.
-
#update_data_role ⇒ String
The IAM role used to read data from the S3 bucket.
-
#update_data_source ⇒ String
The link to the S3 bucket.
Instance Attribute Details
#lo_ra_wan ⇒ Types::LoRaWANUpdateGatewayTaskCreate
The properties that relate to the LoRaWAN wireless gateway.
7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7094 class UpdateWirelessGatewayTaskCreate < Struct.new( :update_data_source, :update_data_role, :lo_ra_wan) SENSITIVE = [] include Aws::Structure end |
#update_data_role ⇒ String
The IAM role used to read data from the S3 bucket.
7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7094 class UpdateWirelessGatewayTaskCreate < Struct.new( :update_data_source, :update_data_role, :lo_ra_wan) SENSITIVE = [] include Aws::Structure end |
#update_data_source ⇒ String
The link to the S3 bucket.
7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7094 class UpdateWirelessGatewayTaskCreate < Struct.new( :update_data_source, :update_data_role, :lo_ra_wan) SENSITIVE = [] include Aws::Structure end |