Class: Aws::IoTWireless::Types::WcdmaObj

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

WCDMA.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lac ⇒ Integer

Location Area Code.

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mcc ⇒ Integer

Mobile Country Code.

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mnc ⇒ Integer

Mobile Network Code.

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#path_loss ⇒ Integer

Path loss, or path attenuation, is the reduction in power density of an electromagnetic wave as it propagates through space.

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rscp ⇒ Integer

Received Signal Code Power (signal power) (dBm).

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#utran_cid ⇒ Integer

UTRAN (UMTS Terrestrial Radio Access Network) Cell Global Identifier.

Returns:

  • (Integer)


7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#wcdma_local_id ⇒ Types::WcdmaLocalId

WCDMA local ID information.

Returns:



7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#wcdma_nmr ⇒ Array<Types::WcdmaNmrObj>

WCDMA object for network measurement reports.

Returns:



7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
# File 'lib/aws-sdk-iotwireless/types.rb', line 7324

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end