Class: Aws::IoTWireless::Types::WiFiCellular
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::WiFiCellular
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
Configuration for WiFi and cellular location payloads.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#confidence_percent ⇒ Integer
Confidence level for WiFi and cellular position estimates, expressed as a percentage.
Instance Attribute Details
#confidence_percent ⇒ Integer
Confidence level for WiFi and cellular position estimates, expressed as a percentage. Valid range: 50–99 inclusive. Defaults to 68 if not specified.
7260 7261 7262 7263 7264 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7260 class WiFiCellular < Struct.new( :confidence_percent) SENSITIVE = [] include Aws::Structure end |