Class: Aws::IoTWireless::Types::WirelessDeviceLogOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The log options for wireless devices and can be used to set log levels for a specific type of wireless device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::WirelessDeviceEventLogOption>

The list of wireless device event log options.



7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-iotwireless/types.rb', line 7351

class WirelessDeviceLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level for a log message. The log levels can be disabled, or set to ERROR to display less verbose logs containing only error information, or to INFO for more detailed logs.



7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-iotwireless/types.rb', line 7351

class WirelessDeviceLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The wireless device type.



7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-iotwireless/types.rb', line 7351

class WirelessDeviceLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end