Class: Aws::IoTWireless::Types::WirelessDeviceStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Information about a wireless device's operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name of the resource.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#destination_name ⇒ String

The name of the destination to which the device is assigned.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#fuota_device_status ⇒ String

The status of a wireless device in a FUOTA task.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the wireless device reporting the data.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

The date and time when the most recent uplink was received.

Theis value is only valid for 3 months.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wan ⇒ Types::LoRaWANListDevice

LoRaWAN device info.



7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#mc_group_id ⇒ Integer

Id of the multicast group.

Returns:

  • (Integer)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_device_status ⇒ String

The status of the wireless device in the multicast group.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the resource.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#positioning ⇒ String

The integration status of the Device Location feature for LoRaWAN and Amazon Sidewalk enabled devices.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalk ⇒ Types::SidewalkListDevice

The Sidewalk account credentials.



7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The wireless device type.

Returns:

  • (String)


7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
# File 'lib/aws-sdk-iotwireless/types.rb', line 7557

class WirelessDeviceStatistics < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :destination_name,
  :last_uplink_received_at,
  :lo_ra_wan,
  :sidewalk,
  :fuota_device_status,
  :multicast_device_status,
  :mc_group_id,
  :positioning)
  SENSITIVE = []
  include Aws::Structure
end