Class: Aws::IoTWireless::Types::WirelessGatewayLogOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

The log options for wireless gateways and can be used to set log levels for a specific type of wireless gateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::WirelessGatewayEventLogOption>

The list of wireless gateway event log options.



7472
7473
7474
7475
7476
7477
7478
# File 'lib/aws-sdk-iotwireless/types.rb', line 7472

class WirelessGatewayLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level for a log message. The log levels can be disabled, or set to ERROR to display less verbose logs containing only error information, or to INFO for more detailed logs.



7472
7473
7474
7475
7476
7477
7478
# File 'lib/aws-sdk-iotwireless/types.rb', line 7472

class WirelessGatewayLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The wireless gateway type.



7472
7473
7474
7475
7476
7477
7478
# File 'lib/aws-sdk-iotwireless/types.rb', line 7472

class WirelessGatewayLogOption < Struct.new(
  :type,
  :log_level,
  :events)
  SENSITIVE = []
  include Aws::Structure
end