Class: Aws::IoTWireless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTWireless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotwireless/client.rb
Overview
An API client for IoTWireless. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTWireless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_aws_account_with_partner_account(params = {}) ⇒ Types::AssociateAwsAccountWithPartnerAccountResponse
Associates a partner account with your AWS account.
-
#associate_multicast_group_with_fuota_task(params = {}) ⇒ Struct
Associate a multicast group with a FUOTA task.
-
#associate_wireless_device_with_fuota_task(params = {}) ⇒ Struct
Associate a wireless device with a FUOTA task.
-
#associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Associates a wireless device with a multicast group.
-
#associate_wireless_device_with_thing(params = {}) ⇒ Struct
Associates a wireless device with a thing.
-
#associate_wireless_gateway_with_certificate(params = {}) ⇒ Types::AssociateWirelessGatewayWithCertificateResponse
Associates a wireless gateway with a certificate.
-
#associate_wireless_gateway_with_thing(params = {}) ⇒ Struct
Associates a wireless gateway with a thing.
-
#cancel_multicast_group_session(params = {}) ⇒ Struct
Cancels an existing multicast group session.
-
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Creates a new destination that maps a device message to an AWS IoT rule.
-
#create_device_profile(params = {}) ⇒ Types::CreateDeviceProfileResponse
Creates a new device profile.
-
#create_fuota_task(params = {}) ⇒ Types::CreateFuotaTaskResponse
Creates a FUOTA task.
-
#create_multicast_group(params = {}) ⇒ Types::CreateMulticastGroupResponse
Creates a multicast group.
-
#create_network_analyzer_configuration(params = {}) ⇒ Types::CreateNetworkAnalyzerConfigurationResponse
Creates a new network analyzer configuration.
-
#create_service_profile(params = {}) ⇒ Types::CreateServiceProfileResponse
Creates a new service profile.
-
#create_wireless_device(params = {}) ⇒ Types::CreateWirelessDeviceResponse
Provisions a wireless device.
-
#create_wireless_gateway(params = {}) ⇒ Types::CreateWirelessGatewayResponse
Provisions a wireless gateway.
-
#create_wireless_gateway_task(params = {}) ⇒ Types::CreateWirelessGatewayTaskResponse
Creates a task for a wireless gateway.
-
#create_wireless_gateway_task_definition(params = {}) ⇒ Types::CreateWirelessGatewayTaskDefinitionResponse
Creates a gateway task definition.
-
#delete_destination(params = {}) ⇒ Struct
Deletes a destination.
-
#delete_device_profile(params = {}) ⇒ Struct
Deletes a device profile.
-
#delete_fuota_task(params = {}) ⇒ Struct
Deletes a FUOTA task.
-
#delete_multicast_group(params = {}) ⇒ Struct
Deletes a multicast group if it is not in use by a FUOTA task.
-
#delete_network_analyzer_configuration(params = {}) ⇒ Struct
Deletes a network analyzer configuration.
-
#delete_queued_messages(params = {}) ⇒ Struct
Remove queued messages from the downlink queue.
-
#delete_service_profile(params = {}) ⇒ Struct
Deletes a service profile.
-
#delete_wireless_device(params = {}) ⇒ Struct
Deletes a wireless device.
-
#delete_wireless_device_import_task(params = {}) ⇒ Struct
Delete an import task.
-
#delete_wireless_gateway(params = {}) ⇒ Struct
Deletes a wireless gateway.
-
#delete_wireless_gateway_task(params = {}) ⇒ Struct
Deletes a wireless gateway task.
-
#delete_wireless_gateway_task_definition(params = {}) ⇒ Struct
Deletes a wireless gateway task definition.
-
#deregister_wireless_device(params = {}) ⇒ Struct
Deregister a wireless device from AWS IoT Wireless.
-
#disassociate_aws_account_from_partner_account(params = {}) ⇒ Struct
Disassociates your AWS account from a partner account.
-
#disassociate_multicast_group_from_fuota_task(params = {}) ⇒ Struct
Disassociates a multicast group from a FUOTA task.
-
#disassociate_wireless_device_from_fuota_task(params = {}) ⇒ Struct
Disassociates a wireless device from a FUOTA task.
-
#disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Disassociates a wireless device from a multicast group.
-
#disassociate_wireless_device_from_thing(params = {}) ⇒ Struct
Disassociates a wireless device from its currently associated thing.
-
#disassociate_wireless_gateway_from_certificate(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated certificate.
-
#disassociate_wireless_gateway_from_thing(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated thing.
-
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets information about a destination.
-
#get_device_profile(params = {}) ⇒ Types::GetDeviceProfileResponse
Gets information about a device profile.
-
#get_event_configuration_by_resource_types(params = {}) ⇒ Types::GetEventConfigurationByResourceTypesResponse
Get the event configuration based on resource types.
-
#get_fuota_task(params = {}) ⇒ Types::GetFuotaTaskResponse
Gets information about a FUOTA task.
-
#get_log_levels_by_resource_types(params = {}) ⇒ Types::GetLogLevelsByResourceTypesResponse
Returns current default log levels or log levels by resource types.
-
#get_metric_configuration(params = {}) ⇒ Types::GetMetricConfigurationResponse
Get the metric configuration status for this AWS account.
-
#get_metrics(params = {}) ⇒ Types::GetMetricsResponse
Get the summary metrics for this AWS account.
-
#get_multicast_group(params = {}) ⇒ Types::GetMulticastGroupResponse
Gets information about a multicast group.
-
#get_multicast_group_session(params = {}) ⇒ Types::GetMulticastGroupSessionResponse
Gets information about a multicast group session.
-
#get_network_analyzer_configuration(params = {}) ⇒ Types::GetNetworkAnalyzerConfigurationResponse
Get network analyzer configuration.
-
#get_partner_account(params = {}) ⇒ Types::GetPartnerAccountResponse
Gets information about a partner account.
-
#get_position(params = {}) ⇒ Types::GetPositionResponse
Get the position information for a given resource.
-
#get_position_configuration(params = {}) ⇒ Types::GetPositionConfigurationResponse
Get position configuration for a given resource.
-
#get_position_estimate(params = {}) ⇒ Types::GetPositionEstimateResponse
Get estimated position information as a payload in GeoJSON format.
-
#get_resource_event_configuration(params = {}) ⇒ Types::GetResourceEventConfigurationResponse
Get the event configuration for a particular resource identifier.
-
#get_resource_log_level(params = {}) ⇒ Types::GetResourceLogLevelResponse
Fetches the log-level override, if any, for a given resource ID and resource type..
-
#get_resource_position(params = {}) ⇒ Types::GetResourcePositionResponse
Get the position information for a given wireless device or a wireless gateway resource.
-
#get_service_endpoint(params = {}) ⇒ Types::GetServiceEndpointResponse
Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.
-
#get_service_profile(params = {}) ⇒ Types::GetServiceProfileResponse
Gets information about a service profile.
-
#get_wireless_device(params = {}) ⇒ Types::GetWirelessDeviceResponse
Gets information about a wireless device.
-
#get_wireless_device_import_task(params = {}) ⇒ Types::GetWirelessDeviceImportTaskResponse
Get information about an import task and count of device onboarding summary information for the import task.
-
#get_wireless_device_statistics(params = {}) ⇒ Types::GetWirelessDeviceStatisticsResponse
Gets operating information about a wireless device.
-
#get_wireless_gateway(params = {}) ⇒ Types::GetWirelessGatewayResponse
Gets information about a wireless gateway.
-
#get_wireless_gateway_certificate(params = {}) ⇒ Types::GetWirelessGatewayCertificateResponse
Gets the ID of the certificate that is currently associated with a wireless gateway.
-
#get_wireless_gateway_firmware_information(params = {}) ⇒ Types::GetWirelessGatewayFirmwareInformationResponse
Gets the firmware version and other information about a wireless gateway.
-
#get_wireless_gateway_statistics(params = {}) ⇒ Types::GetWirelessGatewayStatisticsResponse
Gets operating information about a wireless gateway.
-
#get_wireless_gateway_task(params = {}) ⇒ Types::GetWirelessGatewayTaskResponse
Gets information about a wireless gateway task.
-
#get_wireless_gateway_task_definition(params = {}) ⇒ Types::GetWirelessGatewayTaskDefinitionResponse
Gets information about a wireless gateway task definition.
-
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Lists the destinations registered to your AWS account.
-
#list_device_profiles(params = {}) ⇒ Types::ListDeviceProfilesResponse
Lists the device profiles registered to your AWS account.
-
#list_devices_for_wireless_device_import_task(params = {}) ⇒ Types::ListDevicesForWirelessDeviceImportTaskResponse
List the Sidewalk devices in an import task and their onboarding status.
-
#list_event_configurations(params = {}) ⇒ Types::ListEventConfigurationsResponse
List event configurations where at least one event topic has been enabled.
-
#list_fuota_tasks(params = {}) ⇒ Types::ListFuotaTasksResponse
Lists the FUOTA tasks registered to your AWS account.
-
#list_multicast_groups(params = {}) ⇒ Types::ListMulticastGroupsResponse
Lists the multicast groups registered to your AWS account.
-
#list_multicast_groups_by_fuota_task(params = {}) ⇒ Types::ListMulticastGroupsByFuotaTaskResponse
List all multicast groups associated with a FUOTA task.
-
#list_network_analyzer_configurations(params = {}) ⇒ Types::ListNetworkAnalyzerConfigurationsResponse
Lists the network analyzer configurations.
-
#list_partner_accounts(params = {}) ⇒ Types::ListPartnerAccountsResponse
Lists the partner accounts associated with your AWS account.
-
#list_position_configurations(params = {}) ⇒ Types::ListPositionConfigurationsResponse
List position configurations for a given resource, such as positioning solvers.
-
#list_queued_messages(params = {}) ⇒ Types::ListQueuedMessagesResponse
List queued messages in the downlink queue.
-
#list_service_profiles(params = {}) ⇒ Types::ListServiceProfilesResponse
Lists the service profiles registered to your AWS account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
-
#list_wireless_device_import_tasks(params = {}) ⇒ Types::ListWirelessDeviceImportTasksResponse
List of import tasks and summary information of onboarding status of devices in each import task.
-
#list_wireless_devices(params = {}) ⇒ Types::ListWirelessDevicesResponse
Lists the wireless devices registered to your AWS account.
-
#list_wireless_gateway_task_definitions(params = {}) ⇒ Types::ListWirelessGatewayTaskDefinitionsResponse
List the wireless gateway tasks definitions registered to your AWS account.
-
#list_wireless_gateways(params = {}) ⇒ Types::ListWirelessGatewaysResponse
Lists the wireless gateways registered to your AWS account.
-
#put_position_configuration(params = {}) ⇒ Struct
Put position configuration for a given resource.
-
#put_resource_log_level(params = {}) ⇒ Struct
Sets the log-level override for a resource ID and resource type.
-
#reset_all_resource_log_levels(params = {}) ⇒ Struct
Removes the log-level overrides for all resources; wireless devices, wireless gateways, and FUOTA tasks.
-
#reset_resource_log_level(params = {}) ⇒ Struct
Removes the log-level override, if any, for a specific resource ID and resource type.
-
#send_data_to_multicast_group(params = {}) ⇒ Types::SendDataToMulticastGroupResponse
Sends the specified data to a multicast group.
-
#send_data_to_wireless_device(params = {}) ⇒ Types::SendDataToWirelessDeviceResponse
Sends a decrypted application data frame to a device.
-
#start_bulk_associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Starts a bulk association of all qualifying wireless devices with a multicast group.
-
#start_bulk_disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Starts a bulk disassociatin of all qualifying wireless devices from a multicast group.
-
#start_fuota_task(params = {}) ⇒ Struct
Starts a FUOTA task.
-
#start_multicast_group_session(params = {}) ⇒ Struct
Starts a multicast group session.
-
#start_single_wireless_device_import_task(params = {}) ⇒ Types::StartSingleWirelessDeviceImportTaskResponse
Start import task for a single wireless device.
-
#start_wireless_device_import_task(params = {}) ⇒ Types::StartWirelessDeviceImportTaskResponse
Start import task for provisioning Sidewalk devices in bulk using an S3 CSV file.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#test_wireless_device(params = {}) ⇒ Types::TestWirelessDeviceResponse
Simulates a provisioned device by sending an uplink data payload of ‘Hello`.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
-
#update_destination(params = {}) ⇒ Struct
Updates properties of a destination.
-
#update_event_configuration_by_resource_types(params = {}) ⇒ Struct
Update the event configuration based on resource types.
-
#update_fuota_task(params = {}) ⇒ Struct
Updates properties of a FUOTA task.
-
#update_log_levels_by_resource_types(params = {}) ⇒ Struct
Set default log level, or log levels by resource types.
-
#update_metric_configuration(params = {}) ⇒ Struct
Update the summary metric configuration.
-
#update_multicast_group(params = {}) ⇒ Struct
Updates properties of a multicast group session.
-
#update_network_analyzer_configuration(params = {}) ⇒ Struct
Update network analyzer configuration.
-
#update_partner_account(params = {}) ⇒ Struct
Updates properties of a partner account.
-
#update_position(params = {}) ⇒ Struct
Update the position information of a resource.
-
#update_resource_event_configuration(params = {}) ⇒ Struct
Update the event configuration for a particular resource identifier.
-
#update_resource_position(params = {}) ⇒ Struct
Update the position information of a given wireless device or a wireless gateway resource.
-
#update_wireless_device(params = {}) ⇒ Struct
Updates properties of a wireless device.
-
#update_wireless_device_import_task(params = {}) ⇒ Struct
Update an import task to add more devices to the task.
-
#update_wireless_gateway(params = {}) ⇒ Struct
Updates properties of a wireless gateway.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5490 5491 5492 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5490 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5493 5494 5495 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5493 def errors_module Errors end |
Instance Method Details
#associate_aws_account_with_partner_account(params = {}) ⇒ Types::AssociateAwsAccountWithPartnerAccountResponse
Associates a partner account with your AWS account.
535 536 537 538 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 535 def associate_aws_account_with_partner_account(params = {}, = {}) req = build_request(:associate_aws_account_with_partner_account, params) req.send_request() end |
#associate_multicast_group_with_fuota_task(params = {}) ⇒ Struct
Associate a multicast group with a FUOTA task.
559 560 561 562 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 559 def associate_multicast_group_with_fuota_task(params = {}, = {}) req = build_request(:associate_multicast_group_with_fuota_task, params) req.send_request() end |
#associate_wireless_device_with_fuota_task(params = {}) ⇒ Struct
Associate a wireless device with a FUOTA task.
583 584 585 586 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 583 def associate_wireless_device_with_fuota_task(params = {}, = {}) req = build_request(:associate_wireless_device_with_fuota_task, params) req.send_request() end |
#associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Associates a wireless device with a multicast group.
607 608 609 610 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 607 def associate_wireless_device_with_multicast_group(params = {}, = {}) req = build_request(:associate_wireless_device_with_multicast_group, params) req.send_request() end |
#associate_wireless_device_with_thing(params = {}) ⇒ Struct
Associates a wireless device with a thing.
631 632 633 634 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 631 def associate_wireless_device_with_thing(params = {}, = {}) req = build_request(:associate_wireless_device_with_thing, params) req.send_request() end |
#associate_wireless_gateway_with_certificate(params = {}) ⇒ Types::AssociateWirelessGatewayWithCertificateResponse
Associates a wireless gateway with a certificate.
661 662 663 664 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 661 def associate_wireless_gateway_with_certificate(params = {}, = {}) req = build_request(:associate_wireless_gateway_with_certificate, params) req.send_request() end |
#associate_wireless_gateway_with_thing(params = {}) ⇒ Struct
Associates a wireless gateway with a thing.
685 686 687 688 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 685 def associate_wireless_gateway_with_thing(params = {}, = {}) req = build_request(:associate_wireless_gateway_with_thing, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5463 5464 5465 5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5463 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTWireless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotwireless' context[:gem_version] = '1.84.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_multicast_group_session(params = {}) ⇒ Struct
Cancels an existing multicast group session.
705 706 707 708 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 705 def cancel_multicast_group_session(params = {}, = {}) req = build_request(:cancel_multicast_group_session, params) req.send_request() end |
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Creates a new destination that maps a device message to an AWS IoT rule.
779 780 781 782 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 779 def create_destination(params = {}, = {}) req = build_request(:create_destination, params) req.send_request() end |
#create_device_profile(params = {}) ⇒ Types::CreateDeviceProfileResponse
Creates a new device profile.
870 871 872 873 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 870 def create_device_profile(params = {}, = {}) req = build_request(:create_device_profile, params) req.send_request() end |
#create_fuota_task(params = {}) ⇒ Types::CreateFuotaTaskResponse
Creates a FUOTA task.
976 977 978 979 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 976 def create_fuota_task(params = {}, = {}) req = build_request(:create_fuota_task, params) req.send_request() end |
#create_multicast_group(params = {}) ⇒ Types::CreateMulticastGroupResponse
Creates a multicast group.
1048 1049 1050 1051 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1048 def create_multicast_group(params = {}, = {}) req = build_request(:create_multicast_group, params) req.send_request() end |
#create_network_analyzer_configuration(params = {}) ⇒ Types::CreateNetworkAnalyzerConfigurationResponse
Creates a new network analyzer configuration.
1136 1137 1138 1139 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1136 def create_network_analyzer_configuration(params = {}, = {}) req = build_request(:create_network_analyzer_configuration, params) req.send_request() end |
#create_service_profile(params = {}) ⇒ Types::CreateServiceProfileResponse
Creates a new service profile.
1211 1212 1213 1214 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1211 def create_service_profile(params = {}, = {}) req = build_request(:create_service_profile, params) req.send_request() end |
#create_wireless_device(params = {}) ⇒ Types::CreateWirelessDeviceResponse
Provisions a wireless device.
1355 1356 1357 1358 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1355 def create_wireless_device(params = {}, = {}) req = build_request(:create_wireless_device, params) req.send_request() end |
#create_wireless_gateway(params = {}) ⇒ Types::CreateWirelessGatewayResponse
Provisions a wireless gateway.
<note markdown=“1”> When provisioning a wireless gateway, you might run into duplication errors for the following reasons.
* If you specify a `GatewayEui` value that already exists.
-
If you used a ‘ClientRequestToken` with the same parameters within the last 10 minutes.
To avoid this error, make sure that you use unique identifiers and
parameters for each request within the specified time period.
</note>
1451 1452 1453 1454 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1451 def create_wireless_gateway(params = {}, = {}) req = build_request(:create_wireless_gateway, params) req.send_request() end |
#create_wireless_gateway_task(params = {}) ⇒ Types::CreateWirelessGatewayTaskResponse
Creates a task for a wireless gateway.
1483 1484 1485 1486 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1483 def create_wireless_gateway_task(params = {}, = {}) req = build_request(:create_wireless_gateway_task, params) req.send_request() end |
#create_wireless_gateway_task_definition(params = {}) ⇒ Types::CreateWirelessGatewayTaskDefinitionResponse
Creates a gateway task definition.
1567 1568 1569 1570 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1567 def create_wireless_gateway_task_definition(params = {}, = {}) req = build_request(:create_wireless_gateway_task_definition, params) req.send_request() end |
#delete_destination(params = {}) ⇒ Struct
Deletes a destination.
1587 1588 1589 1590 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1587 def delete_destination(params = {}, = {}) req = build_request(:delete_destination, params) req.send_request() end |
#delete_device_profile(params = {}) ⇒ Struct
Deletes a device profile.
1607 1608 1609 1610 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1607 def delete_device_profile(params = {}, = {}) req = build_request(:delete_device_profile, params) req.send_request() end |
#delete_fuota_task(params = {}) ⇒ Struct
Deletes a FUOTA task.
1627 1628 1629 1630 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1627 def delete_fuota_task(params = {}, = {}) req = build_request(:delete_fuota_task, params) req.send_request() end |
#delete_multicast_group(params = {}) ⇒ Struct
Deletes a multicast group if it is not in use by a FUOTA task.
1647 1648 1649 1650 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1647 def delete_multicast_group(params = {}, = {}) req = build_request(:delete_multicast_group, params) req.send_request() end |
#delete_network_analyzer_configuration(params = {}) ⇒ Struct
Deletes a network analyzer configuration.
1667 1668 1669 1670 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1667 def delete_network_analyzer_configuration(params = {}, = {}) req = build_request(:delete_network_analyzer_configuration, params) req.send_request() end |
#delete_queued_messages(params = {}) ⇒ Struct
Remove queued messages from the downlink queue.
1698 1699 1700 1701 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1698 def (params = {}, = {}) req = build_request(:delete_queued_messages, params) req.send_request() end |
#delete_service_profile(params = {}) ⇒ Struct
Deletes a service profile.
1718 1719 1720 1721 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1718 def delete_service_profile(params = {}, = {}) req = build_request(:delete_service_profile, params) req.send_request() end |
#delete_wireless_device(params = {}) ⇒ Struct
Deletes a wireless device.
1738 1739 1740 1741 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1738 def delete_wireless_device(params = {}, = {}) req = build_request(:delete_wireless_device, params) req.send_request() end |
#delete_wireless_device_import_task(params = {}) ⇒ Struct
Delete an import task.
1758 1759 1760 1761 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1758 def delete_wireless_device_import_task(params = {}, = {}) req = build_request(:delete_wireless_device_import_task, params) req.send_request() end |
#delete_wireless_gateway(params = {}) ⇒ Struct
Deletes a wireless gateway.
<note markdown=“1”> When deleting a wireless gateway, you might run into duplication errors for the following reasons.
* If you specify a `GatewayEui` value that already exists.
-
If you used a ‘ClientRequestToken` with the same parameters within the last 10 minutes.
To avoid this error, make sure that you use unique identifiers and
parameters for each request within the specified time period.
</note>
1791 1792 1793 1794 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1791 def delete_wireless_gateway(params = {}, = {}) req = build_request(:delete_wireless_gateway, params) req.send_request() end |
#delete_wireless_gateway_task(params = {}) ⇒ Struct
Deletes a wireless gateway task.
1811 1812 1813 1814 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1811 def delete_wireless_gateway_task(params = {}, = {}) req = build_request(:delete_wireless_gateway_task, params) req.send_request() end |
#delete_wireless_gateway_task_definition(params = {}) ⇒ Struct
Deletes a wireless gateway task definition. Deleting this task definition does not affect tasks that are currently in progress.
1832 1833 1834 1835 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1832 def delete_wireless_gateway_task_definition(params = {}, = {}) req = build_request(:delete_wireless_gateway_task_definition, params) req.send_request() end |
#deregister_wireless_device(params = {}) ⇒ Struct
Deregister a wireless device from AWS IoT Wireless.
1858 1859 1860 1861 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1858 def deregister_wireless_device(params = {}, = {}) req = build_request(:deregister_wireless_device, params) req.send_request() end |
#disassociate_aws_account_from_partner_account(params = {}) ⇒ Struct
Disassociates your AWS account from a partner account. If ‘PartnerAccountId` and `PartnerType` are `null`, disassociates your AWS account from all partner accounts.
1884 1885 1886 1887 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1884 def disassociate_aws_account_from_partner_account(params = {}, = {}) req = build_request(:disassociate_aws_account_from_partner_account, params) req.send_request() end |
#disassociate_multicast_group_from_fuota_task(params = {}) ⇒ Struct
Disassociates a multicast group from a FUOTA task.
1908 1909 1910 1911 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1908 def disassociate_multicast_group_from_fuota_task(params = {}, = {}) req = build_request(:disassociate_multicast_group_from_fuota_task, params) req.send_request() end |
#disassociate_wireless_device_from_fuota_task(params = {}) ⇒ Struct
Disassociates a wireless device from a FUOTA task.
1932 1933 1934 1935 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1932 def disassociate_wireless_device_from_fuota_task(params = {}, = {}) req = build_request(:disassociate_wireless_device_from_fuota_task, params) req.send_request() end |
#disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Disassociates a wireless device from a multicast group.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1956 def disassociate_wireless_device_from_multicast_group(params = {}, = {}) req = build_request(:disassociate_wireless_device_from_multicast_group, params) req.send_request() end |
#disassociate_wireless_device_from_thing(params = {}) ⇒ Struct
Disassociates a wireless device from its currently associated thing.
1976 1977 1978 1979 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1976 def disassociate_wireless_device_from_thing(params = {}, = {}) req = build_request(:disassociate_wireless_device_from_thing, params) req.send_request() end |
#disassociate_wireless_gateway_from_certificate(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated certificate.
1997 1998 1999 2000 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 1997 def disassociate_wireless_gateway_from_certificate(params = {}, = {}) req = build_request(:disassociate_wireless_gateway_from_certificate, params) req.send_request() end |
#disassociate_wireless_gateway_from_thing(params = {}) ⇒ Struct
Disassociates a wireless gateway from its currently associated thing.
2017 2018 2019 2020 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2017 def disassociate_wireless_gateway_from_thing(params = {}, = {}) req = build_request(:disassociate_wireless_gateway_from_thing, params) req.send_request() end |
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets information about a destination.
2053 2054 2055 2056 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2053 def get_destination(params = {}, = {}) req = build_request(:get_destination, params) req.send_request() end |
#get_device_profile(params = {}) ⇒ Types::GetDeviceProfileResponse
Gets information about a device profile.
2113 2114 2115 2116 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2113 def get_device_profile(params = {}, = {}) req = build_request(:get_device_profile, params) req.send_request() end |
#get_event_configuration_by_resource_types(params = {}) ⇒ Types::GetEventConfigurationByResourceTypesResponse
Get the event configuration based on resource types.
2138 2139 2140 2141 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2138 def get_event_configuration_by_resource_types(params = {}, = {}) req = build_request(:get_event_configuration_by_resource_types, params) req.send_request() end |
#get_fuota_task(params = {}) ⇒ Types::GetFuotaTaskResponse
Gets information about a FUOTA task.
2189 2190 2191 2192 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2189 def get_fuota_task(params = {}, = {}) req = build_request(:get_fuota_task, params) req.send_request() end |
#get_log_levels_by_resource_types(params = {}) ⇒ Types::GetLogLevelsByResourceTypesResponse
Returns current default log levels or log levels by resource types. Based on the resource type, log levels can be returned for wireless device, wireless gateway, or FUOTA task log options.
2229 2230 2231 2232 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2229 def get_log_levels_by_resource_types(params = {}, = {}) req = build_request(:get_log_levels_by_resource_types, params) req.send_request() end |
#get_metric_configuration(params = {}) ⇒ Types::GetMetricConfigurationResponse
Get the metric configuration status for this AWS account.
2246 2247 2248 2249 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2246 def get_metric_configuration(params = {}, = {}) req = build_request(:get_metric_configuration, params) req.send_request() end |
#get_metrics(params = {}) ⇒ Types::GetMetricsResponse
Get the summary metrics for this AWS account.
2306 2307 2308 2309 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2306 def get_metrics(params = {}, = {}) req = build_request(:get_metrics, params) req.send_request() end |
#get_multicast_group(params = {}) ⇒ Types::GetMulticastGroupResponse
Gets information about a multicast group.
2350 2351 2352 2353 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2350 def get_multicast_group(params = {}, = {}) req = build_request(:get_multicast_group, params) req.send_request() end |
#get_multicast_group_session(params = {}) ⇒ Types::GetMulticastGroupSessionResponse
Gets information about a multicast group session.
2380 2381 2382 2383 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2380 def get_multicast_group_session(params = {}, = {}) req = build_request(:get_multicast_group_session, params) req.send_request() end |
#get_network_analyzer_configuration(params = {}) ⇒ Types::GetNetworkAnalyzerConfigurationResponse
Get network analyzer configuration.
2423 2424 2425 2426 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2423 def get_network_analyzer_configuration(params = {}, = {}) req = build_request(:get_network_analyzer_configuration, params) req.send_request() end |
#get_partner_account(params = {}) ⇒ Types::GetPartnerAccountResponse
Gets information about a partner account. If ‘PartnerAccountId` and `PartnerType` are `null`, returns all partner accounts.
2458 2459 2460 2461 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2458 def get_partner_account(params = {}, = {}) req = build_request(:get_partner_account, params) req.send_request() end |
#get_position(params = {}) ⇒ Types::GetPositionResponse
Get the position information for a given resource.
This action is no longer supported. Calls to retrieve the position information should use the [GetResourcePosition] API operation instead.
[1]: docs.aws.amazon.com/iot-wireless/latest/apireference/API_GetResourcePosition.html
2509 2510 2511 2512 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2509 def get_position(params = {}, = {}) req = build_request(:get_position, params) req.send_request() end |
#get_position_configuration(params = {}) ⇒ Types::GetPositionConfigurationResponse
Get position configuration for a given resource.
This action is no longer supported. Calls to retrieve the position configuration should use the [GetResourcePosition] API operation instead.
[1]: docs.aws.amazon.com/iot-wireless/latest/apireference/API_GetResourcePosition.html
2553 2554 2555 2556 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2553 def get_position_configuration(params = {}, = {}) req = build_request(:get_position_configuration, params) req.send_request() end |
#get_position_estimate(params = {}) ⇒ Types::GetPositionEstimateResponse
Get estimated position information as a payload in GeoJSON format. The payload measurement data is resolved using solvers that are provided by third-party vendors.
2751 2752 2753 2754 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2751 def get_position_estimate(params = {}, = {}, &block) req = build_request(:get_position_estimate, params) req.send_request(, &block) end |
#get_resource_event_configuration(params = {}) ⇒ Types::GetResourceEventConfigurationResponse
Get the event configuration for a particular resource identifier.
2800 2801 2802 2803 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2800 def get_resource_event_configuration(params = {}, = {}) req = build_request(:get_resource_event_configuration, params) req.send_request() end |
#get_resource_log_level(params = {}) ⇒ Types::GetResourceLogLevelResponse
Fetches the log-level override, if any, for a given resource ID and resource type..
2833 2834 2835 2836 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2833 def get_resource_log_level(params = {}, = {}) req = build_request(:get_resource_log_level, params) req.send_request() end |
#get_resource_position(params = {}) ⇒ Types::GetResourcePositionResponse
Get the position information for a given wireless device or a wireless gateway resource. The position information uses the [ World Geodetic System (WGS84)].
2872 2873 2874 2875 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2872 def get_resource_position(params = {}, = {}, &block) req = build_request(:get_resource_position, params) req.send_request(, &block) end |
#get_service_endpoint(params = {}) ⇒ Types::GetServiceEndpointResponse
Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.
2905 2906 2907 2908 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2905 def get_service_endpoint(params = {}, = {}) req = build_request(:get_service_endpoint, params) req.send_request() end |
#get_service_profile(params = {}) ⇒ Types::GetServiceProfileResponse
Gets information about a service profile.
2959 2960 2961 2962 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 2959 def get_service_profile(params = {}, = {}) req = build_request(:get_service_profile, params) req.send_request() end |
#get_wireless_device(params = {}) ⇒ Types::GetWirelessDeviceResponse
Gets information about a wireless device.
3050 3051 3052 3053 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3050 def get_wireless_device(params = {}, = {}) req = build_request(:get_wireless_device, params) req.send_request() end |
#get_wireless_device_import_task(params = {}) ⇒ Types::GetWirelessDeviceImportTaskResponse
Get information about an import task and count of device onboarding summary information for the import task.
3102 3103 3104 3105 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3102 def get_wireless_device_import_task(params = {}, = {}) req = build_request(:get_wireless_device_import_task, params) req.send_request() end |
#get_wireless_device_statistics(params = {}) ⇒ Types::GetWirelessDeviceStatisticsResponse
Gets operating information about a wireless device.
3152 3153 3154 3155 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3152 def get_wireless_device_statistics(params = {}, = {}) req = build_request(:get_wireless_device_statistics, params) req.send_request() end |
#get_wireless_gateway(params = {}) ⇒ Types::GetWirelessGatewayResponse
Gets information about a wireless gateway.
3206 3207 3208 3209 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3206 def get_wireless_gateway(params = {}, = {}) req = build_request(:get_wireless_gateway, params) req.send_request() end |
#get_wireless_gateway_certificate(params = {}) ⇒ Types::GetWirelessGatewayCertificateResponse
Gets the ID of the certificate that is currently associated with a wireless gateway.
3235 3236 3237 3238 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3235 def get_wireless_gateway_certificate(params = {}, = {}) req = build_request(:get_wireless_gateway_certificate, params) req.send_request() end |
#get_wireless_gateway_firmware_information(params = {}) ⇒ Types::GetWirelessGatewayFirmwareInformationResponse
Gets the firmware version and other information about a wireless gateway.
3264 3265 3266 3267 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3264 def get_wireless_gateway_firmware_information(params = {}, = {}) req = build_request(:get_wireless_gateway_firmware_information, params) req.send_request() end |
#get_wireless_gateway_statistics(params = {}) ⇒ Types::GetWirelessGatewayStatisticsResponse
Gets operating information about a wireless gateway.
3294 3295 3296 3297 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3294 def get_wireless_gateway_statistics(params = {}, = {}) req = build_request(:get_wireless_gateway_statistics, params) req.send_request() end |
#get_wireless_gateway_task(params = {}) ⇒ Types::GetWirelessGatewayTaskResponse
Gets information about a wireless gateway task.
3328 3329 3330 3331 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3328 def get_wireless_gateway_task(params = {}, = {}) req = build_request(:get_wireless_gateway_task, params) req.send_request() end |
#get_wireless_gateway_task_definition(params = {}) ⇒ Types::GetWirelessGatewayTaskDefinitionResponse
Gets information about a wireless gateway task definition.
3369 3370 3371 3372 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3369 def get_wireless_gateway_task_definition(params = {}, = {}) req = build_request(:get_wireless_gateway_task_definition, params) req.send_request() end |
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Lists the destinations registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3411 3412 3413 3414 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3411 def list_destinations(params = {}, = {}) req = build_request(:list_destinations, params) req.send_request() end |
#list_device_profiles(params = {}) ⇒ Types::ListDeviceProfilesResponse
Lists the device profiles registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3455 def list_device_profiles(params = {}, = {}) req = build_request(:list_device_profiles, params) req.send_request() end |
#list_devices_for_wireless_device_import_task(params = {}) ⇒ Types::ListDevicesForWirelessDeviceImportTaskResponse
List the Sidewalk devices in an import task and their onboarding status.
3509 3510 3511 3512 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3509 def list_devices_for_wireless_device_import_task(params = {}, = {}) req = build_request(:list_devices_for_wireless_device_import_task, params) req.send_request() end |
#list_event_configurations(params = {}) ⇒ Types::ListEventConfigurationsResponse
List event configurations where at least one event topic has been enabled.
3561 3562 3563 3564 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3561 def list_event_configurations(params = {}, = {}) req = build_request(:list_event_configurations, params) req.send_request() end |
#list_fuota_tasks(params = {}) ⇒ Types::ListFuotaTasksResponse
Lists the FUOTA tasks registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3600 3601 3602 3603 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3600 def list_fuota_tasks(params = {}, = {}) req = build_request(:list_fuota_tasks, params) req.send_request() end |
#list_multicast_groups(params = {}) ⇒ Types::ListMulticastGroupsResponse
Lists the multicast groups registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3639 3640 3641 3642 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3639 def list_multicast_groups(params = {}, = {}) req = build_request(:list_multicast_groups, params) req.send_request() end |
#list_multicast_groups_by_fuota_task(params = {}) ⇒ Types::ListMulticastGroupsByFuotaTaskResponse
List all multicast groups associated with a FUOTA task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3680 3681 3682 3683 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3680 def list_multicast_groups_by_fuota_task(params = {}, = {}) req = build_request(:list_multicast_groups_by_fuota_task, params) req.send_request() end |
#list_network_analyzer_configurations(params = {}) ⇒ Types::ListNetworkAnalyzerConfigurationsResponse
Lists the network analyzer configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3718 3719 3720 3721 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3718 def list_network_analyzer_configurations(params = {}, = {}) req = build_request(:list_network_analyzer_configurations, params) req.send_request() end |
#list_partner_accounts(params = {}) ⇒ Types::ListPartnerAccountsResponse
Lists the partner accounts associated with your AWS account.
3755 3756 3757 3758 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3755 def list_partner_accounts(params = {}, = {}) req = build_request(:list_partner_accounts, params) req.send_request() end |
#list_position_configurations(params = {}) ⇒ Types::ListPositionConfigurationsResponse
List position configurations for a given resource, such as positioning solvers.
This action is no longer supported. Calls to retrieve position information should use the [GetResourcePosition] API operation instead.
[1]: docs.aws.amazon.com/iot-wireless/latest/apireference/API_GetResourcePosition.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3811 3812 3813 3814 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3811 def list_position_configurations(params = {}, = {}) req = build_request(:list_position_configurations, params) req.send_request() end |
#list_queued_messages(params = {}) ⇒ Types::ListQueuedMessagesResponse
List queued messages in the downlink queue.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3865 3866 3867 3868 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3865 def (params = {}, = {}) req = build_request(:list_queued_messages, params) req.send_request() end |
#list_service_profiles(params = {}) ⇒ Types::ListServiceProfilesResponse
Lists the service profiles registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3904 3905 3906 3907 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3904 def list_service_profiles(params = {}, = {}) req = build_request(:list_service_profiles, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
3932 3933 3934 3935 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3932 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_wireless_device_import_tasks(params = {}) ⇒ Types::ListWirelessDeviceImportTasksResponse
List of import tasks and summary information of onboarding status of devices in each import task.
3982 3983 3984 3985 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 3982 def list_wireless_device_import_tasks(params = {}, = {}) req = build_request(:list_wireless_device_import_tasks, params) req.send_request() end |
#list_wireless_devices(params = {}) ⇒ Types::ListWirelessDevicesResponse
Lists the wireless devices registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4066 4067 4068 4069 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4066 def list_wireless_devices(params = {}, = {}) req = build_request(:list_wireless_devices, params) req.send_request() end |
#list_wireless_gateway_task_definitions(params = {}) ⇒ Types::ListWirelessGatewayTaskDefinitionsResponse
List the wireless gateway tasks definitions registered to your AWS account.
4114 4115 4116 4117 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4114 def list_wireless_gateway_task_definitions(params = {}, = {}) req = build_request(:list_wireless_gateway_task_definitions, params) req.send_request() end |
#list_wireless_gateways(params = {}) ⇒ Types::ListWirelessGatewaysResponse
Lists the wireless gateways registered to your AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4168 4169 4170 4171 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4168 def list_wireless_gateways(params = {}, = {}) req = build_request(:list_wireless_gateways, params) req.send_request() end |
#put_position_configuration(params = {}) ⇒ Struct
Put position configuration for a given resource.
This action is no longer supported. Calls to update the position configuration should use the [UpdateResourcePosition] API operation instead.
[1]: docs.aws.amazon.com/iot-wireless/latest/apireference/API_UpdateResourcePosition.html
4217 4218 4219 4220 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4217 def put_position_configuration(params = {}, = {}) req = build_request(:put_position_configuration, params) req.send_request() end |
#put_resource_log_level(params = {}) ⇒ Struct
Sets the log-level override for a resource ID and resource type. A limit of 200 log level override can be set per account.
4250 4251 4252 4253 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4250 def put_resource_log_level(params = {}, = {}) req = build_request(:put_resource_log_level, params) req.send_request() end |
#reset_all_resource_log_levels(params = {}) ⇒ Struct
Removes the log-level overrides for all resources; wireless devices, wireless gateways, and FUOTA tasks.
4262 4263 4264 4265 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4262 def reset_all_resource_log_levels(params = {}, = {}) req = build_request(:reset_all_resource_log_levels, params) req.send_request() end |
#reset_resource_log_level(params = {}) ⇒ Struct
Removes the log-level override, if any, for a specific resource ID and resource type. It can be used for a wireless device, a wireless gateway, or a FUOTA task.
4290 4291 4292 4293 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4290 def reset_resource_log_level(params = {}, = {}) req = build_request(:reset_resource_log_level, params) req.send_request() end |
#send_data_to_multicast_group(params = {}) ⇒ Types::SendDataToMulticastGroupResponse
Sends the specified data to a multicast group.
4328 4329 4330 4331 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4328 def send_data_to_multicast_group(params = {}, = {}) req = build_request(:send_data_to_multicast_group, params) req.send_request() end |
#send_data_to_wireless_device(params = {}) ⇒ Types::SendDataToWirelessDeviceResponse
Sends a decrypted application data frame to a device.
4386 4387 4388 4389 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4386 def send_data_to_wireless_device(params = {}, = {}) req = build_request(:send_data_to_wireless_device, params) req.send_request() end |
#start_bulk_associate_wireless_device_with_multicast_group(params = {}) ⇒ Struct
Starts a bulk association of all qualifying wireless devices with a multicast group.
4422 4423 4424 4425 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4422 def start_bulk_associate_wireless_device_with_multicast_group(params = {}, = {}) req = build_request(:start_bulk_associate_wireless_device_with_multicast_group, params) req.send_request() end |
#start_bulk_disassociate_wireless_device_from_multicast_group(params = {}) ⇒ Struct
Starts a bulk disassociatin of all qualifying wireless devices from a multicast group.
4458 4459 4460 4461 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4458 def start_bulk_disassociate_wireless_device_from_multicast_group(params = {}, = {}) req = build_request(:start_bulk_disassociate_wireless_device_from_multicast_group, params) req.send_request() end |
#start_fuota_task(params = {}) ⇒ Struct
Starts a FUOTA task.
4484 4485 4486 4487 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4484 def start_fuota_task(params = {}, = {}) req = build_request(:start_fuota_task, params) req.send_request() end |
#start_multicast_group_session(params = {}) ⇒ Struct
Starts a multicast group session.
4514 4515 4516 4517 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4514 def start_multicast_group_session(params = {}, = {}) req = build_request(:start_multicast_group_session, params) req.send_request() end |
#start_single_wireless_device_import_task(params = {}) ⇒ Types::StartSingleWirelessDeviceImportTaskResponse
Start import task for a single wireless device.
4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4593 def start_single_wireless_device_import_task(params = {}, = {}) req = build_request(:start_single_wireless_device_import_task, params) req.send_request() end |
#start_wireless_device_import_task(params = {}) ⇒ Types::StartWirelessDeviceImportTaskResponse
Start import task for provisioning Sidewalk devices in bulk using an S3 CSV file.
4669 4670 4671 4672 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4669 def start_wireless_device_import_task(params = {}, = {}) req = build_request(:start_wireless_device_import_task, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
4699 4700 4701 4702 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4699 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_wireless_device(params = {}) ⇒ Types::TestWirelessDeviceResponse
Simulates a provisioned device by sending an uplink data payload of ‘Hello`.
4726 4727 4728 4729 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4726 def test_wireless_device(params = {}, = {}) req = build_request(:test_wireless_device, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
4750 4751 4752 4753 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4750 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_destination(params = {}) ⇒ Struct
Updates properties of a destination.
4786 4787 4788 4789 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4786 def update_destination(params = {}, = {}) req = build_request(:update_destination, params) req.send_request() end |
#update_event_configuration_by_resource_types(params = {}) ⇒ Struct
Update the event configuration based on resource types.
4847 4848 4849 4850 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4847 def update_event_configuration_by_resource_types(params = {}, = {}) req = build_request(:update_event_configuration_by_resource_types, params) req.send_request() end |
#update_fuota_task(params = {}) ⇒ Struct
Updates properties of a FUOTA task.
4920 4921 4922 4923 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4920 def update_fuota_task(params = {}, = {}) req = build_request(:update_fuota_task, params) req.send_request() end |
#update_log_levels_by_resource_types(params = {}) ⇒ Struct
Set default log level, or log levels by resource types. This can be for wireless device, wireless gateway, or FUOTA task log options, and is used to control the log messages that’ll be displayed in CloudWatch.
4990 4991 4992 4993 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 4990 def update_log_levels_by_resource_types(params = {}, = {}) req = build_request(:update_log_levels_by_resource_types, params) req.send_request() end |
#update_metric_configuration(params = {}) ⇒ Struct
Update the summary metric configuration.
5012 5013 5014 5015 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5012 def update_metric_configuration(params = {}, = {}) req = build_request(:update_metric_configuration, params) req.send_request() end |
#update_multicast_group(params = {}) ⇒ Struct
Updates properties of a multicast group session.
5051 5052 5053 5054 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5051 def update_multicast_group(params = {}, = {}) req = build_request(:update_multicast_group, params) req.send_request() end |
#update_network_analyzer_configuration(params = {}) ⇒ Struct
Update network analyzer configuration.
5120 5121 5122 5123 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5120 def update_network_analyzer_configuration(params = {}, = {}) req = build_request(:update_network_analyzer_configuration, params) req.send_request() end |
#update_partner_account(params = {}) ⇒ Struct
Updates properties of a partner account.
5150 5151 5152 5153 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5150 def update_partner_account(params = {}, = {}) req = build_request(:update_partner_account, params) req.send_request() end |
#update_position(params = {}) ⇒ Struct
Update the position information of a resource.
This action is no longer supported. Calls to update the position information should use the [UpdateResourcePosition] API operation instead.
[1]: docs.aws.amazon.com/iot-wireless/latest/apireference/API_UpdateResourcePosition.html
5186 5187 5188 5189 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5186 def update_position(params = {}, = {}) req = build_request(:update_position, params) req.send_request() end |
#update_resource_event_configuration(params = {}) ⇒ Struct
Update the event configuration for a particular resource identifier.
5261 5262 5263 5264 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5261 def update_resource_event_configuration(params = {}, = {}) req = build_request(:update_resource_event_configuration, params) req.send_request() end |
#update_resource_position(params = {}) ⇒ Struct
Update the position information of a given wireless device or a wireless gateway resource. The position coordinates are based on the [ World Geodetic System (WGS84)].
5305 5306 5307 5308 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5305 def update_resource_position(params = {}, = {}) req = build_request(:update_resource_position, params) req.send_request() end |
#update_wireless_device(params = {}) ⇒ Struct
Updates properties of a wireless device.
5381 5382 5383 5384 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5381 def update_wireless_device(params = {}, = {}) req = build_request(:update_wireless_device, params) req.send_request() end |
#update_wireless_device_import_task(params = {}) ⇒ Struct
Update an import task to add more devices to the task.
5407 5408 5409 5410 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5407 def update_wireless_device_import_task(params = {}, = {}) req = build_request(:update_wireless_device_import_task, params) req.send_request() end |
#update_wireless_gateway(params = {}) ⇒ Struct
Updates properties of a wireless gateway.
5454 5455 5456 5457 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5454 def update_wireless_gateway(params = {}, = {}) req = build_request(:update_wireless_gateway, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5483 5484 5485 |
# File 'lib/aws-sdk-iotwireless/client.rb', line 5483 def waiter_names [] end |