Class: Aws::IoTWireless::Types::FuotaTaskLogOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::FuotaTaskLogOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The log options for FUOTA tasks and can be used to set log levels for a specific type of FUOTA task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::FuotaTaskEventLogOption>
The list of FUOTA task event log options.
-
#log_level ⇒ String
The log level for a log message.
-
#type ⇒ String
The FUOTA task type.
Instance Attribute Details
#events ⇒ Array<Types::FuotaTaskEventLogOption>
The list of FUOTA task event log options.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1858 class FuotaTaskLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level for a log message. The log levels can be disabled, or
set to ERROR to display less verbose logs containing only error
information, or to INFO for more detailed logs.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1858 class FuotaTaskLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The FUOTA task type.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 1858 class FuotaTaskLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |