Class: Aws::IoTWireless::Types::GetPositionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::GetPositionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accuracy ⇒ Types::Accuracy
The accuracy of the estimated position in meters.
-
#position ⇒ Array<Float>
The position information of the resource.
-
#solver_provider ⇒ String
The vendor of the positioning solver.
-
#solver_type ⇒ String
The type of solver used to identify the position of the resource.
-
#solver_version ⇒ String
The version of the positioning solver.
-
#timestamp ⇒ String
The timestamp at which the device’s position was determined.
Instance Attribute Details
#accuracy ⇒ Types::Accuracy
The accuracy of the estimated position in meters. An empty value indicates that no position data is available. A value of ‘0.0’ value indicates that position data is available. This data corresponds to the position information that you specified instead of the position computed by solver.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |
#position ⇒ Array<Float>
The position information of the resource.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |
#solver_provider ⇒ String
The vendor of the positioning solver.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |
#solver_type ⇒ String
The type of solver used to identify the position of the resource.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |
#solver_version ⇒ String
The version of the positioning solver.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ String
The timestamp at which the device’s position was determined.
2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2451 class GetPositionResponse < Struct.new( :position, :accuracy, :solver_type, :solver_provider, :solver_version, :timestamp) SENSITIVE = [] include Aws::Structure end |