Class: Aws::IoTWireless::Types::GetServiceEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::GetServiceEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_type ⇒ String
The service type for which to get endpoint information about.
Instance Attribute Details
#service_type ⇒ String
The service type for which to get endpoint information about. Can be
CUPS for the Configuration and Update Server endpoint, or LNS
for the LoRaWAN Network Server endpoint.
2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2601 class GetServiceEndpointRequest < Struct.new( :service_type) SENSITIVE = [] include Aws::Structure end |