Class: Aws::IoTWireless::Types::GetWirelessDeviceImportTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::GetWirelessDeviceImportTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) of the import task.
-
#creation_time ⇒ Time
The time at which the import task was created.
-
#destination_name ⇒ String
The name of the destination that’s assigned to the wireless devices in the import task.
-
#failed_imported_device_count ⇒ Integer
The number of devices in the import task that failed to onboard to the import task.
-
#id ⇒ String
The identifier of the import task for which information is retrieved.
-
#initialized_imported_device_count ⇒ Integer
The number of devices in the import task that are waiting for the control log to start processing.
-
#onboarded_imported_device_count ⇒ Integer
The number of devices in the import task that have been onboarded to the import task.
-
#pending_imported_device_count ⇒ Integer
The number of devices in the import task that are waiting in the import task queue to be onboarded.
-
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.
-
#sidewalk ⇒ Types::SidewalkGetStartImportInfo
The Sidewalk-related information about an import task.
-
#status ⇒ String
The import task status.
-
#status_reason ⇒ String
The reason for the provided status information, such as a validation error that causes the import task to fail.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) of the import task.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time at which the import task was created.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The name of the destination that’s assigned to the wireless devices in the import task.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#failed_imported_device_count ⇒ Integer
The number of devices in the import task that failed to onboard to the import task.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the import task for which information is retrieved.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#initialized_imported_device_count ⇒ Integer
The number of devices in the import task that are waiting for the control log to start processing.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#onboarded_imported_device_count ⇒ Integer
The number of devices in the import task that have been onboarded to the import task.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#pending_imported_device_count ⇒ Integer
The number of devices in the import task that are waiting in the import task queue to be onboarded.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Types::SidewalkGetStartImportInfo
The Sidewalk-related information about an import task.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The import task status.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the provided status information, such as a validation error that causes the import task to fail.
2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 2693 class GetWirelessDeviceImportTaskResponse < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |