Class: Aws::IoTWireless::Types::ListFuotaTasksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fuota_task_listArray<Types::FuotaTask>

Lists the FUOTA tasks registered to your AWS account.

Returns:



3505
3506
3507
3508
3509
3510
# File 'lib/aws-sdk-iotwireless/types.rb', line 3505

class ListFuotaTasksResponse < Struct.new(
  :next_token,
  :fuota_task_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
# File 'lib/aws-sdk-iotwireless/types.rb', line 3505

class ListFuotaTasksResponse < Struct.new(
  :next_token,
  :fuota_task_list)
  SENSITIVE = []
  include Aws::Structure
end