Class: Aws::IoTWireless::Types::ListFuotaTasksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListFuotaTasksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fuota_task_list ⇒ Array<Types::FuotaTask>
Lists the FUOTA tasks registered to your AWS account.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results.
Instance Attribute Details
#fuota_task_list ⇒ Array<Types::FuotaTask>
Lists the FUOTA tasks registered to your AWS account.
3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3505 class ListFuotaTasksResponse < Struct.new( :next_token, :fuota_task_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3505 class ListFuotaTasksResponse < Struct.new( :next_token, :fuota_task_list) SENSITIVE = [] include Aws::Structure end |