Class: Aws::IoTWireless::Types::ListQueuedMessagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::ListQueuedMessagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of a given wireless device which the downlink message packets are being sent.
-
#max_results ⇒ Integer
The maximum number of results to return in this operation.
-
#next_token ⇒ String
To retrieve the next set of results, the
nextTokenvalue from a previous response; otherwise null to receive the first set of results. -
#wireless_device_type ⇒ String
The wireless device type, whic can be either Sidewalk or LoRaWAN.
Instance Attribute Details
#id ⇒ String
The ID of a given wireless device which the downlink message packets are being sent.
3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819 class ListQueuedMessagesRequest < Struct.new( :id, :next_token, :max_results, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in this operation.
3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819 class ListQueuedMessagesRequest < Struct.new( :id, :next_token, :max_results, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
To retrieve the next set of results, the nextToken value from a
previous response; otherwise null to receive the first set of
results.
3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819 class ListQueuedMessagesRequest < Struct.new( :id, :next_token, :max_results, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |
#wireless_device_type ⇒ String
The wireless device type, whic can be either Sidewalk or LoRaWAN.
3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 3819 class ListQueuedMessagesRequest < Struct.new( :id, :next_token, :max_results, :wireless_device_type) SENSITIVE = [] include Aws::Structure end |