Class: Aws::IoTWireless::Types::ListWirelessGatewayTaskDefinitionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to use to get the next set of results, or null if there are no additional results.



3921
3922
3923
3924
3925
3926
# File 'lib/aws-sdk-iotwireless/types.rb', line 3921

class ListWirelessGatewayTaskDefinitionsResponse < Struct.new(
  :next_token,
  :task_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#task_definitionsArray<Types::UpdateWirelessGatewayTaskEntry>

The list of task definitions.



3921
3922
3923
3924
3925
3926
# File 'lib/aws-sdk-iotwireless/types.rb', line 3921

class ListWirelessGatewayTaskDefinitionsResponse < Struct.new(
  :next_token,
  :task_definitions)
  SENSITIVE = []
  include Aws::Structure
end