Class: Aws::IoTWireless::Types::LoRaWANMulticast
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::LoRaWANMulticast
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The LoRaWAN information that is to be used with the multicast group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
-
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages.
-
#rf_region ⇒ String
Supported RfRegions.
Instance Attribute Details
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4518 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages. The multicast message will be sent to each gateway in the list, with the transmission interval as the time interval between each message.
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4518 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#rf_region ⇒ String
Supported RfRegions
4518 4519 4520 4521 4522 4523 4524 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4518 class LoRaWANMulticast < Struct.new( :rf_region, :dl_class, :participating_gateways) SENSITIVE = [] include Aws::Structure end |