Class: Aws::IoTWireless::Types::LoRaWANMulticastGet
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::LoRaWANMulticastGet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The LoRaWAN information that is to be returned from getting multicast group information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
-
#number_of_devices_in_group ⇒ Integer
Number of devices that are associated to the multicast group.
-
#number_of_devices_requested ⇒ Integer
Number of devices that are requested to be associated with the multicast group.
-
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages.
-
#rf_region ⇒ String
Supported RfRegions.
Instance Attribute Details
#dl_class ⇒ String
DlClass for LoRaWAM, valid values are ClassB and ClassC.
4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4553 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#number_of_devices_in_group ⇒ Integer
Number of devices that are associated to the multicast group.
4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4553 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#number_of_devices_requested ⇒ Integer
Number of devices that are requested to be associated with the multicast group.
4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4553 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#participating_gateways ⇒ Types::ParticipatingGatewaysMulticast
Specify the list of gateways to which you want to send the multicast downlink messages. The multicast message will be sent to each gateway in the list, with the transmission interval as the time interval between each message.
4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4553 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways) SENSITIVE = [] include Aws::Structure end |
#rf_region ⇒ String
Supported RfRegions
4553 4554 4555 4556 4557 4558 4559 4560 4561 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 4553 class LoRaWANMulticastGet < Struct.new( :rf_region, :dl_class, :number_of_devices_requested, :number_of_devices_in_group, :participating_gateways) SENSITIVE = [] include Aws::Structure end |