Class: Aws::IoTWireless::Types::LteObj

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

LTE object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eutran_cidInteger

E-UTRAN (Evolved Universal Terrestrial Radio Access Network) Cell Global Identifier.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_local_idTypes::LteLocalId

LTE local identification (local ID) information.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_nmrArray<Types::LteNmrObj>

LTE object for network measurement reports.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#lte_timing_advanceInteger

LTE timing advance.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mccInteger

Mobile Country Code.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mncInteger

Mobile Network Code.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#nr_capableBoolean

Parameter that determines whether the LTE object is capable of supporting NR (new radio).



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rsrpInteger

Signal power of the reference signal received, measured in dBm (decibel-milliwatts).



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rsrqFloat

Signal quality of the reference Signal received, measured in decibels (dB).



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#tacInteger

LTE tracking area code.



4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/aws-sdk-iotwireless/types.rb', line 4902

class LteObj < Struct.new(
  :mcc,
  :mnc,
  :eutran_cid,
  :tac,
  :lte_local_id,
  :lte_timing_advance,
  :rsrp,
  :rsrq,
  :nr_capable,
  :lte_nmr)
  SENSITIVE = []
  include Aws::Structure
end