Class: Aws::IoTWireless::Types::PositionConfigurationItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::PositionConfigurationItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The wrapper for a position configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
The position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.
-
#resource_identifier ⇒ String
Resource identifier for the position configuration.
-
#resource_type ⇒ String
Resource type of the resource for the position configuration.
-
#solvers ⇒ Types::PositionSolverDetails
The details of the positioning solver object used to compute the location.
Instance Attribute Details
#destination ⇒ String
The position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.
5230 5231 5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5230 class PositionConfigurationItem < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
Resource identifier for the position configuration.
5230 5231 5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5230 class PositionConfigurationItem < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Resource type of the resource for the position configuration.
5230 5231 5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5230 class PositionConfigurationItem < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |
#solvers ⇒ Types::PositionSolverDetails
The details of the positioning solver object used to compute the location.
5230 5231 5232 5233 5234 5235 5236 5237 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 5230 class PositionConfigurationItem < Struct.new( :resource_identifier, :resource_type, :solvers, :destination) SENSITIVE = [] include Aws::Structure end |