Class: Aws::IoTWireless::Types::UpdateWirelessDeviceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A new description of the resource.

Returns:

  • (String)


7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#destination_nameString

The name of the new destination for the device.

Returns:

  • (String)


7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the resource to update.

Returns:

  • (String)


7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#lo_ra_wanTypes::LoRaWANUpdateDevice

The updated wireless device's configuration.



7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The new name of the resource.

The following special characters aren't accepted: <>^#~$

Returns:

  • (String)


7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#positioningString

The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.

Returns:

  • (String)


7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalkTypes::SidewalkUpdateWirelessDevice

The updated sidewalk properties.



7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051

class UpdateWirelessDeviceRequest < Struct.new(
  :id,
  :destination_name,
  :name,
  :description,
  :lo_ra_wan,
  :positioning,
  :sidewalk)
  SENSITIVE = []
  include Aws::Structure
end