Class: Aws::IoTWireless::Types::UpdateWirelessDeviceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::UpdateWirelessDeviceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A new description of the resource.
-
#destination_name ⇒ String
The name of the new destination for the device.
-
#id ⇒ String
The ID of the resource to update.
-
#lo_ra_wan ⇒ Types::LoRaWANUpdateDevice
The updated wireless device's configuration.
-
#name ⇒ String
The new name of the resource.
-
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.
-
#sidewalk ⇒ Types::SidewalkUpdateWirelessDevice
The updated sidewalk properties.
Instance Attribute Details
#description ⇒ String
A new description of the resource.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The name of the new destination for the device.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the resource to update.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#lo_ra_wan ⇒ Types::LoRaWANUpdateDevice
The updated wireless device's configuration.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new name of the resource.
<>^#~$
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Sidewalk devices.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Types::SidewalkUpdateWirelessDevice
The updated sidewalk properties.
7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7051 class UpdateWirelessDeviceRequest < Struct.new( :id, :destination_name, :name, :description, :lo_ra_wan, :positioning, :sidewalk) SENSITIVE = [] include Aws::Structure end |