Class: Aws::IoTWireless::Types::WcdmaObj
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::WcdmaObj
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
WCDMA.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lac ⇒ Integer
Location Area Code.
-
#mcc ⇒ Integer
Mobile Country Code.
-
#mnc ⇒ Integer
Mobile Network Code.
-
#path_loss ⇒ Integer
Path loss, or path attenuation, is the reduction in power density of an electromagnetic wave as it propagates through space.
-
#rscp ⇒ Integer
Received Signal Code Power (signal power) (dBm).
-
#utran_cid ⇒ Integer
UTRAN (UMTS Terrestrial Radio Access Network) Cell Global Identifier.
-
#wcdma_local_id ⇒ Types::WcdmaLocalId
WCDMA local ID information.
-
#wcdma_nmr ⇒ Array<Types::WcdmaNmrObj>
WCDMA object for network measurement reports.
Instance Attribute Details
#lac ⇒ Integer
Location Area Code.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#mcc ⇒ Integer
Mobile Country Code.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#mnc ⇒ Integer
Mobile Network Code.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#path_loss ⇒ Integer
Path loss, or path attenuation, is the reduction in power density of an electromagnetic wave as it propagates through space.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#rscp ⇒ Integer
Received Signal Code Power (signal power) (dBm).
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#utran_cid ⇒ Integer
UTRAN (UMTS Terrestrial Radio Access Network) Cell Global Identifier.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#wcdma_local_id ⇒ Types::WcdmaLocalId
WCDMA local ID information.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |
#wcdma_nmr ⇒ Array<Types::WcdmaNmrObj>
WCDMA object for network measurement reports.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7222 class WcdmaObj < Struct.new( :mcc, :mnc, :lac, :utran_cid, :wcdma_local_id, :rscp, :path_loss, :wcdma_nmr) SENSITIVE = [] include Aws::Structure end |