Class: Aws::IoTWireless::Types::WcdmaObj

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

WCDMA.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lacInteger

Location Area Code.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mccInteger

Mobile Country Code.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#mncInteger

Mobile Network Code.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#path_lossInteger

Path loss, or path attenuation, is the reduction in power density of an electromagnetic wave as it propagates through space.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#rscpInteger

Received Signal Code Power (signal power) (dBm).



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#utran_cidInteger

UTRAN (UMTS Terrestrial Radio Access Network) Cell Global Identifier.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#wcdma_local_idTypes::WcdmaLocalId

WCDMA local ID information.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end

#wcdma_nmrArray<Types::WcdmaNmrObj>

WCDMA object for network measurement reports.



7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
# File 'lib/aws-sdk-iotwireless/types.rb', line 7203

class WcdmaObj < Struct.new(
  :mcc,
  :mnc,
  :lac,
  :utran_cid,
  :wcdma_local_id,
  :rscp,
  :path_loss,
  :wcdma_nmr)
  SENSITIVE = []
  include Aws::Structure
end