Class: Aws::IoTWireless::Types::WirelessDeviceImportTask

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotwireless/types.rb

Overview

Information about an import task for wireless devices.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) of the wireless device import task.

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time at which the import task was created.

Returns:

  • (Time)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_nameString

The name of the Sidewalk destination that that describes the IoT rule to route messages from the device in the import task that will be onboarded to AWS IoT Wireless

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#failed_imported_device_countInteger

The summary information of count of wireless devices in an import task that failed to onboarded to the import task.

Returns:

  • (Integer)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the wireless device import task.

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#initialized_imported_device_countInteger

The summary information of count of wireless devices that are waiting for the control log to be added to an import task.

Returns:

  • (Integer)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#onboarded_imported_device_countInteger

The summary information of count of wireless devices in an import task that have been onboarded to the import task.

Returns:

  • (Integer)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#pending_imported_device_countInteger

The summary information of count of wireless devices in an import task that are waiting in the queue to be onboarded.

Returns:

  • (Integer)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#positioningString

The integration status of the Device Location feature for Sidewalk devices.

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#sidewalkTypes::SidewalkGetStartImportInfo

The Sidewalk-related information of the wireless device import task.



7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status information of the wireless device import task.

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason that provides additional information about the import task status.

Returns:

  • (String)


7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377

class WirelessDeviceImportTask < Struct.new(
  :id,
  :arn,
  :destination_name,
  :positioning,
  :sidewalk,
  :creation_time,
  :status,
  :status_reason,
  :initialized_imported_device_count,
  :pending_imported_device_count,
  :onboarded_imported_device_count,
  :failed_imported_device_count)
  SENSITIVE = []
  include Aws::Structure
end