Class: Aws::IoTWireless::Types::WirelessDeviceImportTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::WirelessDeviceImportTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
Information about an import task for wireless devices.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) of the wireless device import task.
-
#creation_time ⇒ Time
The time at which the import task was created.
-
#destination_name ⇒ String
The name of the Sidewalk destination that that describes the IoT rule to route messages from the device in the import task that will be onboarded to AWS IoT Wireless.
-
#failed_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that failed to onboarded to the import task.
-
#id ⇒ String
The ID of the wireless device import task.
-
#initialized_imported_device_count ⇒ Integer
The summary information of count of wireless devices that are waiting for the control log to be added to an import task.
-
#onboarded_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that have been onboarded to the import task.
-
#pending_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that are waiting in the queue to be onboarded.
-
#positioning ⇒ String
The integration status of the Device Location feature for Sidewalk devices.
-
#sidewalk ⇒ Types::SidewalkGetStartImportInfo
The Sidewalk-related information of the wireless device import task.
-
#status ⇒ String
The status information of the wireless device import task.
-
#status_reason ⇒ String
The reason that provides additional information about the import task status.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) of the wireless device import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time at which the import task was created.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The name of the Sidewalk destination that that describes the IoT rule to route messages from the device in the import task that will be onboarded to AWS IoT Wireless
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#failed_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that failed to onboarded to the import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the wireless device import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#initialized_imported_device_count ⇒ Integer
The summary information of count of wireless devices that are waiting for the control log to be added to an import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#onboarded_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that have been onboarded to the import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#pending_imported_device_count ⇒ Integer
The summary information of count of wireless devices in an import task that are waiting in the queue to be onboarded.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ String
The integration status of the Device Location feature for Sidewalk devices.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Types::SidewalkGetStartImportInfo
The Sidewalk-related information of the wireless device import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status information of the wireless device import task.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason that provides additional information about the import task status.
7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7377 class WirelessDeviceImportTask < Struct.new( :id, :arn, :destination_name, :positioning, :sidewalk, :creation_time, :status, :status_reason, :initialized_imported_device_count, :pending_imported_device_count, :onboarded_imported_device_count, :failed_imported_device_count) SENSITIVE = [] include Aws::Structure end |