Class: Aws::IoTWireless::Types::WirelessDeviceLogOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::WirelessDeviceLogOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
The log options for wireless devices and can be used to set log levels for a specific type of wireless device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::WirelessDeviceEventLogOption>
The list of wireless device event log options.
-
#log_level ⇒ String
The log level for a log message.
-
#type ⇒ String
The wireless device type.
Instance Attribute Details
#events ⇒ Array<Types::WirelessDeviceEventLogOption>
The list of wireless device event log options.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7411 class WirelessDeviceLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level for a log message. The log levels can be disabled, or
set to ERROR to display less verbose logs containing only error
information, or to INFO for more detailed logs.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7411 class WirelessDeviceLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The wireless device type.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7411 class WirelessDeviceLogOption < Struct.new( :type, :log_level, :events) SENSITIVE = [] include Aws::Structure end |