Class: Aws::IoTWireless::Types::WirelessDeviceStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTWireless::Types::WirelessDeviceStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotwireless/types.rb
Overview
Information about a wireless device's operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name of the resource.
-
#destination_name ⇒ String
The name of the destination to which the device is assigned.
-
#fuota_device_status ⇒ String
The status of a wireless device in a FUOTA task.
-
#id ⇒ String
The ID of the wireless device reporting the data.
-
#last_uplink_received_at ⇒ String
The date and time when the most recent uplink was received.
-
#lo_ra_wan ⇒ Types::LoRaWANListDevice
LoRaWAN device info.
-
#mc_group_id ⇒ Integer
Id of the multicast group.
-
#multicast_device_status ⇒ String
The status of the wireless device in the multicast group.
-
#name ⇒ String
The name of the resource.
-
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Amazon Sidewalk enabled devices.
-
#sidewalk ⇒ Types::SidewalkListDevice
The Sidewalk account credentials.
-
#type ⇒ String
The wireless device type.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name of the resource.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
The name of the destination to which the device is assigned.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#fuota_device_status ⇒ String
The status of a wireless device in a FUOTA task.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the wireless device reporting the data.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#last_uplink_received_at ⇒ String
The date and time when the most recent uplink was received.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#lo_ra_wan ⇒ Types::LoRaWANListDevice
LoRaWAN device info.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#mc_group_id ⇒ Integer
Id of the multicast group.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#multicast_device_status ⇒ String
The status of the wireless device in the multicast group.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#positioning ⇒ String
The integration status of the Device Location feature for LoRaWAN and Amazon Sidewalk enabled devices.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#sidewalk ⇒ Types::SidewalkListDevice
The Sidewalk account credentials.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The wireless device type.
7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-iotwireless/types.rb', line 7474 class WirelessDeviceStatistics < Struct.new( :arn, :id, :type, :name, :destination_name, :last_uplink_received_at, :lo_ra_wan, :sidewalk, :fuota_device_status, :multicast_device_status, :mc_group_id, :positioning) SENSITIVE = [] include Aws::Structure end |